/*
This software is allowed to use under GPL or you need to obtain Commercial or Enterise License
to use it in non-GPL project. Please contact sales@dhtmlx.com for details
*/

/*
2012 June 22
*/
.dhx_skin_settings{
	border-top:1px solid #adadad;
	display:none;
	color:#0986b0;
}
.dhx_schedulerbar{
	background-color: #b7b7b7;background: -o-linear-gradient(top, #d6d6d6 0% ,  #b7b7b7 100%);background: -ms-linear-gradient(top, #d6d6d6 0% ,  #b7b7b7 100%);background: -moz-linear-gradient(top, #d6d6d6 0% ,  #b7b7b7 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#d6d6d6), color-stop(1,  #b7b7b7));;
}
.dhx_scheduler .dhx_el_button input, .dhx_scheduler .dhx_el_formbutton input {
	text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.6);
	border:1px solid #626262;
	color: #ffffff;
	border-radius: 4px;-webkit-border-radius:4px; -moz-border-radius:4px;
}
.dhx_scheduler .dhx_el_button input{
	-moz-box-shadow: inset 0px 1px 1px #b9d3dc, 0px 1px  #ffffff;-webkit-box-shadow: inset 0px 1px 1px #b9d3dc, 0px 1px  #ffffff;
	background-color:#6799aa;background: -o-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -ms-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -moz-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#9cbcc6), color-stop(30%, #80aab8), color-stop(60%,#6799aa), color-stop(100%, #4f899d));;
}
.dhx_scheduler .dhx_touch.dhx_el_button input{
	background-color: #4f899d;background: -o-linear-gradient(top, #6799aa 0% ,  #4f899d 100%);background: -ms-linear-gradient(top, #6799aa 0% ,  #4f899d 100%);background: -moz-linear-gradient(top, #6799aa 0% ,  #4f899d 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#6799aa), color-stop(1,  #4f899d));
}
.dhx_scheduler .dhx_el_button.add input{
	font-size: 24px;
	line-height: 13px;
	padding: 1px 1px 3px 1px;
}
.dhx_scheduler .dhx_all_segments{
	float:none !important;
	border:1px solid #626262;
	height:30px;
	-o-box-shadow:   0px  1px 0px #ffffff;-ms-box-shadow:   0px  1px 0px #ffffff;-moz-box-shadow:   0px  1px 0px #ffffff;-webkit-box-shadow:   0px  1px 0px #ffffff;
}
.dhx_schedulerbar .dhx_el_segmented .segment_0,.dhx_schedulerbar .dhx_el_segmented .segment_1, .dhx_schedulerbar .dhx_el_segmented .segment_N {
	background-color: #ccd2d4;background: -o-linear-gradient(top, #eef5f8 0% ,  #ccd2d4 100%);background: -ms-linear-gradient(top, #eef5f8 0% ,  #ccd2d4 100%);background: -moz-linear-gradient(top, #eef5f8 0% ,  #ccd2d4 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#eef5f8), color-stop(1,  #ccd2d4));;
}
.dhx_schedulerbar .dhx_el_segmented .selected.segment_0 ,.dhx_schedulerbar .dhx_el_segmented .selected.segment_1, .dhx_schedulerbar .dhx_el_segmented .selected.segment_N {
	background-color:#6799aa;background: -o-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -ms-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -moz-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#9cbcc6), color-stop(30%, #80aab8), color-stop(60%,#6799aa), color-stop(100%, #4f899d));;
}
.dhx_scheduler .dhx_el_button.cancel input, .dhx_scheduler .dhx_el_prevbutton input, .confirm .dhx_el_bigbutton input{
	-moz-box-shadow: inset 0px 1px 1px #f5f7f8, 0px 1px  #ffffff;-webkit-box-shadow: inset 0px 1px 1px #f5f7f8, 0px 1px  #ffffff;
	text-shadow: 0px 1px 0px #ffffff;
    background-color: #ccd2d4;background: -o-linear-gradient(top, #eef5f8 0% ,  #ccd2d4 100%);background: -ms-linear-gradient(top, #eef5f8 0% ,  #ccd2d4 100%);background: -moz-linear-gradient(top, #eef5f8 0% ,  #ccd2d4 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#eef5f8), color-stop(1,  #ccd2d4));;
	color: #757575
}
.dhx_scheduler .dhx_touch.dhx_el_button.cancel input, .dhx_scheduler .dhx_touch.dhx_el_prevbutton input, .confirm .dhx_touch.dhx_el_bigbutton input{
	text-shadow: 0px 1px 0px #ffffff;
    background-color: #ccd2d4;background: -o-linear-gradient(top, #ccd2d4 0% ,  #ccd2d4 100%);background: -ms-linear-gradient(top, #ccd2d4 0% ,  #ccd2d4 100%);background: -moz-linear-gradient(top, #ccd2d4 0% ,  #ccd2d4 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#ccd2d4), color-stop(1,  #ccd2d4));;
	#757575 : setBrightness(#303030, 0.459);
}
.dhx_scheduler .dhx_inp_toggle_left_off, .dhx_scheduler .dhx_inp_toggle_right_off {
	text-shadow: 0px 1px 0px #ffffff;
	background-color: #ccd2d4;background: -o-linear-gradient(top, #eef5f8 0% ,  #ccd2d4 100%);background: -ms-linear-gradient(top, #eef5f8 0% ,  #ccd2d4 100%);background: -moz-linear-gradient(top, #eef5f8 0% ,  #ccd2d4 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#eef5f8), color-stop(1,  #ccd2d4));;
	color: #757575
}
.dhx_scheduler .dhx_inp_toggle_left_on, .dhx_scheduler .dhx_inp_toggle_right_on {
	-o-box-shadow: inset 0px -1px 1px #4f899d;-ms-box-shadow: inset 0px -1px 1px #4f899d;-moz-box-shadow: inset 0px -1px 1px #4f899d;-webkit-box-shadow: inset 0px -1px 1px #4f899d;
}
.dhx_dayevents_scale_item {
	-moz-user-select:-moz-none;
	border-bottom:1px solid #D4D4D4;
	color: #303030;
	font-family:"Helvetica World","HelveticaNeue","Helvetica Neue","HelveticaNeueRoman","Helvetica","Tahoma","Geneva","Arial",sans-serif;
	white-space:nowrap;
}
.dhx_dayevents_scale_hour{
	float: left;
	text-align: center;
	font-size: 16px;
	vertical-align:middle;
	font-weight: bold;
}
.dhx_dayevents_scale_top, .dhx_dayevents_scale_bottom {
	font-size: 10px;
	float: left;
	text-align:center;
}
.dhx_dayevents_scale_top{
	border-bottom:1px dotted #d3d3d3;
}
.dhx_dayevents_scale_minute{
	background-color: #ededed;
	border-bottom:1px dotted #d3d3d3;
	float:left;
}
.dhx_dayevents_scale_event {
	float:left;
}
.dhx_dayevents_event_item{
	position:absolute;
	border-radius: 4px;-webkit-border-radius:4px; -moz-border-radius:4px;
	font-size: 12px;
	background-color: #e6f8ff;
	border:1px solid #78a4b4;
	font-family:"Helvetica World","HelveticaNeue","Helvetica Neue","HelveticaNeueRoman","Helvetica","Tahoma","Geneva","Arial",sans-serif;
}
.dhx_scheduler .dhx_topbar{
	background-color:#e8e8e8;background: -o-linear-gradient(top, #ffffff 0% , #e8e8e8 50% , #c2c2c2 100%);background: -ms-linear-gradient(top, #ffffff 0% , #e8e8e8 50% , #c2c2c2 100%);background:  -moz-linear-gradient(top, #ffffff 0% , #e8e8e8 50% , #c2c2c2 100%);background:  -webkit-gradient(linear, left top, left bottom, color-stop(0,#ffffff), color-stop(0.5,#e8e8e8), color-stop(1, #c2c2c2));
    font-size:18px;
	font-weight:bold;
	color: #757575;
	text-shadow:    0px 1px 0px #ffffff;
}
.dhx_list_events_item{
	position:relative;
	background-color: #ffffff;
}
.dhx_event_overall{
	padding:10px;
}
.dhx_list_events_item .dhx_day_title{
	height:15px;
	line-height:15px;
	width:75px;
	position:absolute;
	left:1px;
	top:0px;
	background: #518a9e;
	border-radius: 2px;
	text-align:center;
	border-radius: 2px;-webkit-border-radius:2px; -moz-border-radius:2px;
	-o-box-shadow:  1px 1px 1px #1c2329;-ms-box-shadow:  1px 1px 1px #1c2329;-moz-box-shadow:  1px 1px 1px #1c2329;-webkit-box-shadow:  1px 1px 1px #1c2329;;
	text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.6);
	font-size: 14px;
	padding:1px;
	color: #ffffff;
}
.dhx_list_events_item .dhx_event_marker{
	display:inline-block;
	margin-left:5px;
	margin-top:5px;
	height:10px;
	width:10px;
	border-radius: 6px;-webkit-border-radius:6px; -moz-border-radius:6px;
	background-color: #e6f8ff;
	border:1px solid #78a4b4;
	vertical-align:top;
}
.dhx_list_events_item .dhx_event_time{
	display:inline-block;
	width:70px;
	font-size:16px;
	padding-top:8px;
}
.dhx_list_events_item .dhx_event_text{
	display:inline-block;
	padding-left:4px;
	overflow:hidden;
	height:22px;
	vertical-align:top;
	white-space:nowrap;
}
.dhx_scheduler .dhx_cal_day_num.dhx_cal_current_day {
	background-color: #ededed;background: -o-linear-gradient(top, #b9b9b9 0% ,  #ededed 100%);background: -ms-linear-gradient(top, #b9b9b9 0% ,  #ededed 100%);background: -moz-linear-gradient(top, #b9b9b9 0% ,  #ededed 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#b9b9b9), color-stop(1,  #ededed));;
	border-color: #626262;
}
.dhx_scheduler .dhx_cal_day_num.dhx_cal_selected_day{
	background-color:#6799aa;background: -o-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -ms-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -moz-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#9cbcc6), color-stop(30%, #80aab8), color-stop(60%,#6799aa), color-stop(100%, #4f899d));;
}
.dhx_cal_day_num.dhx_cal_selected_day span{
	color:#ffffff;
}
.dhx_cal_day_num{
	position:relative;
}
.dhx_cal_day_num .day_with_events{
	position:absolute;
	bottom:0px;
	right:0px;
	border-color: transparent #4f899d #4f899d transparent;
  	border-style:solid;
  	border-width:5px;
 	width:0;
  	height:0;
}
.dhx_cal_day_num.dhx_cal_selected_day .day_with_events{
	border-color: transparent #ffffff #ffffff transparent;
}
.dhx_cal_prev_button div {
	background-position: 0 -92px;
	width:28px;
	height:29px;
	top:6px;
}
.dhx_cal_next_button div {
	background-position: 0 -106px;
	width:28px;
	height:29px;
	top:6px;
}
.dhx_list_day_events_item{
	background-color:#ffffff;
}
.dhx_list_day_events_item .dhx_event_marker{
	display:inline-block;
	margin-top:16px;
	margin-left:5px;
	height:10px;
	width:10px;
	border-radius: 6px;-webkit-border-radius:6px; -moz-border-radius:6px;;
	background-color: #e6f8ff;
	border:1px solid #78a4b4;
}
.dhx_list_day_events_item .dhx_event_time{
	display:inline-block;
	width:auto;
	height:42px;
	line-height:42px;
	padding-left:5px;
}
.dhx_list_day_events_item .dhx_event_text{
	display:inline-block;
	padding-left:10px;
	line-height:42px;
}
.selected_event{
	margin:5px;
	background-color: #e6f8ff;
	border:1px solid #78a4b4;
	border-radius: 5px;-webkit-border-radius:5px; -moz-border-radius:5px;;
	padding:3px 6px;
}
.selected_event .event_title{
	font-weight:bold;
}
.selected_event .event_text{
	font-size:12px;
}
.dhx_scheduler .dhx_el_formbutton.delete input{
	background-color:#921313;background: -o-linear-gradient(top, #cd7c7c 0% , #921313 100%);background: -ms-linear-gradient(top, #cd7c7c 0% , #921313 100%);background: -moz-linear-gradient(top, #cd7c7c 0% , #921313 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#cd7c7c), color-stop(1, #921313));
	height:38px;
	font-size:16px;
	-moz-box-shadow: inset 0px 1px 1px #e7b6b6, 0px 1px #EBEBEB0;-webkit-box-shadow: inset 0px 1px 1px #e7b6b6, 0px 1px #EBEBEB0;
}
.invalid .dhx_inp_text_border{
	border-color:#cc0000;
}
.invalid .dhx_inp_list {
	color:#cc0000;
}
.dhx_el_box div.dhx_inp_text {
	font-size: $(inputFontSize)px;
	line-height: 31px;
}
.dhx_el_box .dhx_arrow_icon{
	background-position: 0 -106px;
	right: 17px;
}
.form_calendar .dhx_cal_time_select{
	background-color: #ededed;background: -o-linear-gradient(top, #b9b9b9 0% ,  #ededed 100%);background: -ms-linear-gradient(top, #b9b9b9 0% ,  #ededed 100%);background: -moz-linear-gradient(top, #b9b9b9 0% ,  #ededed 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#b9b9b9), color-stop(1,  #ededed));;
}
.dhx_win_body{
	font-weight:bold;
}
.dhx_el_bigbutton input, .dhx_el_bigroundbutton input{
	height:40px;
	line-height:40px;
}
.dhx_el_bigroundbutton input, .alert .dhx_el_bigbutton input{
	background-color:#6799aa;background: -o-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -ms-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -moz-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#9cbcc6), color-stop(30%, #80aab8), color-stop(60%,#6799aa), color-stop(100%, #4f899d));;
}
.dhx_el_bigroundbutton{
	padding-top:0px;
}
.dhx_el_rectext {
	display:inline-block;
	font-size:18px;
}
.dhx_el_rectext input {
	font-size: 18px;
	line-height: 28px;
}
.dhx_recurring .endless_button .dhx_el_roundbutton input{
	border-radius: 6px;-webkit-border-radius:6px; -moz-border-radius:6px;
}
.dhx_recurring .dhx_rounded .dhx_scroll_cont{
	margin:10px;
	border-radius: 10px;-webkit-border-radius:10px; -moz-border-radius:10px;;
	border: 1px solid #adadad;
	position:relative;
}
.dhx_recurring .dhx_rounded .dhx_scroll_cont > .dhx_list_item:first-child{
	border-radius:0;border-top-left-radius: 9px; border-top-right-radius: 9px;-webkit-border-radius:0;-moz-border-radius:0;-webkit-border-top-left-radius: 9px; -webkit-border-top-right-radius: 9px; -moz-border-radius-topleft: 9px; -moz-border-radius-topright: 9px;
}
.dhx_recurring .dhx_rounded .dhx_scroll_cont > .dhx_list_item:last-child{
	border-radius:0;border-bottom-left-radius: 9px; border-bottom-right-radius: 9px;-webkit-border-radius:0;-moz-border-radius:0;-webkit-border-bottom-left-radius: 9px; -webkit-border-bottom-right-radius: 9px; -moz-border-radius-bottomleft: 9px; -moz-border-radius-bottomright: 9px;
}
.dhx_recurring .dhx_rounded .dhx_list_item{
	position:relative;
}
.dhx_recurring .dhx_list_item .dhx_arrow_icon{
	background-position: 0 -106px;
	right: 17px;
}
.rec_list .dhx_list__item_selected{
	background-color:#6799aa;background: -o-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -ms-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -moz-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#9cbcc6), color-stop(30%, #80aab8), color-stop(60%,#6799aa), color-stop(100%, #4f899d));;
}
.dhx_recurring .dhx_rec_table{
	background-color: #f2f2f2;
	border-top: 1px solid #d3d3d3;
}
.dhx_recurring .dhx_rec_table .dhx_cal_day_num{
	border-color: #adadad;
	border-width: 0 1px 1px 0;
	font-weight: bold;
}
.dhx_accordionitem_header{
	border-top-width:1px !important;
	border-bottom-width:1px !important;
}
.dhx_recurring .dhx_el_label{
	font-size:19px;
}
.dhx_recurring .dhx_accordionitem_header .blured{
	color:#9c9c9c
}
.dhx_recurring .dhx_accordionitem_header .dhx_accordionitem_button.collapsed, .dhx_accordionitem_header .dhx_accordionitem_button{
	background-position:0px 0px;
	height: 27px;
	width: 27px;
}
.dhx_recurring .dhx_accordionitem_header .dhx_accordionitem_button{
	display:none;
}
.dhx_recurring .dhx_accordionitem_header .radio{
	margin-top:8px;
	margin-left:7px;
	height: 24px;
	width: 24px;
	border-radius: 12px;-webkit-border-radius:12px; -moz-border-radius:12px;
	-o-box-shadow:  0px 1px 1px #e8e8e8;-ms-box-shadow:  0px 1px 1px #e8e8e8;-moz-box-shadow:  0px 1px 1px #e8e8e8;-webkit-box-shadow:  0px 1px 1px #e8e8e8;
	border: 1px solid #c9c9c9;
	float:left;
}
.dhx_recurring .dhx_accordionitem_header .radio.blured{
	margin-top:12px;
}
.dhx_recurring .dhx_accordionitem_header .radio .on{
	margin: 6px 6px;
	height: 12px;
	width: 12px;
	border-radius: 6px;-webkit-border-radius:6px; -moz-border-radius:6px;
	background-color:#6799aa;background: -o-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -ms-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -moz-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#9cbcc6), color-stop(30%, #80aab8), color-stop(60%,#6799aa), color-stop(100%, #4f899d));;
}
.dhx_recurring .dhx_accordionitem_header .dhx_accordionitem_label .text{
	padding-left:7px;
	float:left;
}
html,body{
	-moz-user-select:-moz-none;
	-webkit-user-select:none;
	-user-select:none;
	-webkit-tap-highlight-color: rgba(0,0,0,0);
}
.dhx_scroll_x {
	width:50px;
	height:4px !important;
	left:1px; bottom:3px;
	background:rgba(0, 0, 0, 0.4);
	position:absolute; 
	border-radius: 4px;-webkit-border-radius:4px; -moz-border-radius:4px;
	margin:0px !important;
	padding:0px !important;
}
.dhx_scroll_y {
	width:4px !important;
	height:50px;
	top:1px; right:3px; 
	background:rgba(0, 0, 0, 0.4);
	position:absolute; 
	border-radius: 4px;-webkit-border-radius:4px; -moz-border-radius:4px;
	margin:0px !important;
	padding:0px !important;
}
.dhx_scroll_cont{
	width:100%;
	height:auto;
	overflow:hidden;
	clear:both;
}
html, body{
	padding:0;
	margin:0;
	overflow:auto;
}
.dhx_view{
	font-family: "Helvetica World", "HelveticaNeue", "Helvetica Neue", "HelveticaNeueRoman", "Helvetica", "Tahoma", "Geneva", "Arial", sans-serif;
	
	color:#303030;
	border:0px solid #adadad;
}
.dhx_view{
	overflow:hidden;
	vertical-align:top;
	background-color:#ffffff;
	cursor:default;
}
.dhx_layout_wide, .dhx_layout_head{
	background-color:#c2dae2;
}
.dhx_loading_overlay{
	width:100%;
	height:100%;
	
	position:absolute;
	z-index:99999;
	
	background-image:url(./imgs/loading.png);
	background-repeat:no-repeat;
	background-position:center;
}
.dhx_drag_zone{
	position:absolute;
	background-color:white;
	padding:5px;
}
.dhx_cal_month {
	border-bottom:  1px solid #d3d3d3;
    height:         39px;
    line-height:    39px;
    text-align: center;
    vertical-align: middle;

    background-color:#e8e8e8;background: -o-linear-gradient(top, #ffffff 0% , #e8e8e8 50% , #c2c2c2 100%);background: -ms-linear-gradient(top, #ffffff 0% , #e8e8e8 50% , #c2c2c2 100%);background:  -moz-linear-gradient(top, #ffffff 0% , #e8e8e8 50% , #c2c2c2 100%);background:  -webkit-gradient(linear, left top, left bottom, color-stop(0,#ffffff), color-stop(0.5,#e8e8e8), color-stop(1, #c2c2c2));
    font-size:18px;
	font-weight:bold;
	color: #757575;
	text-shadow:    0px 1px 0px #ffffff;
    position: relative;
}
 .dhx_cal_week_header, .dhx_cal_day_name, .dhx_cal_day_num, .dhx_next_month, .dhx_prev_month, .dhx_cal_week_num{
	border-color: #fcfcfc #fcfcfc  #c2c2c2 #c2c2c2;
    border-width: 1px;
    border-style: solid;
    text-align: center;
}
.dhx_cal_header{
	overflow:hidden;
}
.dhx_cal_week_header, .dhx_cal_day_name{
	line-height:21px;
	 border-width: 0px 1px 1px 1px;
}
.dhx_cal_header div:first-child{
	border-left-width:0px;
}
.dhx_cal_week_header, .dhx_cal_day_name {
	font-size: 12px;
    display: inline-block;
    background-color: #dedede;
}
.dhx_cal_week_header{
	border-left-width:0px;
}
.dhx_cal_day_name_last {
	border-right-width:0px;
}
.dhx_cal_day_num, .dhx_next_month, .dhx_prev_month, .dhx_cal_week_num {
	background-color:   #f2f2f2;
    font-size:18px;
	font-weight:bold;
	color: #757575;
	text-shadow:    0px 1px 0px #ffffff;
    font-size:16px;
}
.dhx_week_numbers .dhx_cal_week_num {
	font-size:      12px;
    font-weight:bold;
    color:#2f2f2f;
    background-color: #dedede;
}
.dhx_cal_day_num {
	cursor:         pointer;
}
.dhx_cal_day_num.dhx_cal_current_day {
	background:     #c2c2c2;
    border-color: #c2c2c2 #c2c2c2  #c2c2c2 #c2c2c2;
}
.dhx_cal_day_num.dhx_cal_selected_day {
	background-color:#6799aa;background: -o-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -ms-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -moz-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#9cbcc6), color-stop(30%, #80aab8), color-stop(60%,#6799aa), color-stop(100%, #4f899d));;
    color: #ffffff;
	text-shadow: 0px -1px 0px rgba(0, 0, 0, 0.6);
    border-color:  #6c8289;
}
.dhx_cal_day_num_bborder {
	border-bottom: 0;
}
.dhx_cal_day_num_rborder {
	border-right: 0;
}
.dhx_cal_day_name_last {
	border-right:0;
}
.dhx_cal_time_select {
	border-top: 1px solid #d3d3d3;
    background-color:   #f2f2f2;
    height:34px;
	padding-top:4px;
    text-align: center;
    vertical-align: middle;
}
.dhx_cal_time_select select{
	font-size:15px;
	height:26px;
}
.dhx_minute_select{
	margin-left:5px;
}
.dhx_cal_body {
	margin-left: -1px;
}
.dhx_cal_prev_button, .dhx_cal_next_button {
	cursor:     pointer;
    position:   absolute;
    top: 0;
    width:          39px;
    height:         39px;
    font-size: 0;
    line-height:        39px;
    vertical-align: middle;
}
.dhx_cal_prev_button {
	left:       10px;
}
.dhx_cal_next_button {
	right:      10px;
}
.dhx_cal_prev_button div, .dhx_cal_next_button div  {
	width:  9px;
    height:     13px;
    position: absolute;
    top:        15px;
}
.dhx_cal_prev_button div {
	background-image: url(./imgs/images.png);
	background-repeat:no-repeat;
    background-position: 0 -92px;

    left: 5px;
}
.dhx_cal_next_button div {
	background-image: url(./imgs/images.png);
	background-repeat:no-repeat;
    background-position: 0 -106px;
    
    right: 5px;
}
input:focus{
	outline: none 0;
}
input::-moz-focus-inner{
	border:0;
}
.dhx_el_icon div{
	background-image:url(./imgs/bar_icons_sprite.png);
	background-repeat:no-repeat;
	width:16px; height:16px;
	margin:10px;
}
.dhx_el_icon_refresh {
	background-position:0 0;
}
.dhx_el_icon_save {
	background-position:-22px 0;
}
.dhx_el_icon_add {
	background-position:-44px 0;
}
.dhx_el_icon_delete {
	background-position:-66px 0;
}
.dhx_el_icon_open {
	background-position:-88px 0;
}
.dhx_el_icon_run {
	background-position:-110px 0;
}
.dhx_el_icon_help {
	background-position:-132px 0;
}
.dhx_el_icon_new {
	background-position:-154px 0;
}
.dhx_el_icon_edit {
	background-position:-176px 0;
}
.dhx_el_icon_search {
	background-position:-198px 0;
}
.dhx_el_icon_close {
	background-position:-220px 0;
}
.dhx_el_label {
	height: 42px;
    line-height:42px;
}
.dhx_el_label div{
	box-sizing: border-box;
	-ms-box-sizing: border-box;
	-moz-box-sizing: border-box;
	-webkit-box-sizing: border-box;
	padding: 0px 5px;	
	font-weight:bold;
	font-size:22px;
	text-shadow: 0px 1px 0px #ffffff;
	color: #6a6a6a
}
.dhx_inp_form_button, .dhx_el_button input, .dhx_el_formbutton input, .dhx_el_prevbutton input , .dhx_el_nextbutton input ,.dhx_el_roundbutton input{
	height: 32px;

	font-size: 14px;
    font-weight: bold;

	color: #6d6d6d;
    background-color: #dedede;background: -o-linear-gradient(top, #fcfcfc 0% ,  #dedede 100%);background: -ms-linear-gradient(top, #fcfcfc 0% ,  #dedede 100%);background: -moz-linear-gradient(top, #fcfcfc 0% ,  #dedede 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#fcfcfc), color-stop(1,  #dedede));;
	-moz-box-shadow: inset 0px 1px 1px #ffffff, 0px 1px  #b9d3dc;-webkit-box-shadow: inset 0px 1px 1px #ffffff, 0px 1px  #b9d3dc;
    border: 1px solid #afafaf;
    border-radius: 8px;-webkit-border-radius:8px; -moz-border-radius:8px;

    margin:5px;
	padding: 0px 10px;
}
.dhx_el_nextbutton input{
	padding-right:0px;
	padding-left:10px;
}
.dhx_el_prevbutton input{
	padding-left:0px;
	padding-right:10px;
}
.dhx_el_defaultbutton input, .dhx_el_select select{
	margin:5px;
	font-size: 14px;
    font-weight: bold;
    height: 32px;
    color:
}
.dhx_inp_form_button, .dhx_el_formbutton input{
	-moz-box-shadow: inset 0px 1px 1px #ffffff, 0px 1px  #b9d3dc;-webkit-box-shadow: inset 0px 1px 1px #ffffff, 0px 1px  #b9d3dc;
	border-radius: 4px;-webkit-border-radius:4px; -moz-border-radius:4px;
	border: 1px solid #6B8352;
	border-bottom: 1px solid #3A640D;
	color: white;
	background-color: #579418;background: -o-linear-gradient(top, #A0C07C 0% ,  #579418 100%);background: -ms-linear-gradient(top, #A0C07C 0% ,  #579418 100%);background: -moz-linear-gradient(top, #A0C07C 0% ,  #579418 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#A0C07C), color-stop(1,  #579418));;
	text-shadow: 0px -1px 0px rgba(0, 0, 0, 0.6);
}
.dhx_touch.dhx_el_formbutton input{
	background-color: #579418;background: -o-linear-gradient(top, #72a53b 0% ,  #579418 100%);background: -ms-linear-gradient(top, #72a53b 0% ,  #579418 100%);background: -moz-linear-gradient(top, #72a53b 0% ,  #579418 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#72a53b), color-stop(1,  #579418));;
}
.dhx_el_arrow{
	width: 18px;
	height:32px;
}
.dhx_el_nextbutton input {
	border-top-right-radius: 0px;
	border-bottom-right-radius: 0px;
	-webkit-border-top-right-radius: 0px;
	-webkit-border-bottom-right-radius: 0px;
	border-right-width:0px;
}
.dhx_el_nextbutton .dhx_el_arrow{
	background:url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAA8AAAAiCAYAAACA5IOiAAABvklEQVRIiZ3VsWrjQBCA4d8myFVUqYr9AgKDcWyDwZX7pNiXiN/ijru3iF9ii+QtjliFbFzYzQpOqLAEBuFCKuaKRMfhWD5tBpYtho9ZNKNdtNaitX7iC9H+2J+11ve2uFUUhYRhSBRFAF2lVNy4sojQ7/dxXRfgt03ltoggIsxmMzqdDlrrN2ssIsznc4B7rfWLNRYRptMpwIPW+tkau67LcDgEePpfCz9hEcHzPHzfh/cWPtTiukSv16Pb7QK81M3AxcrV8n0fz/MA3rTWd1ZYRBgMBtze3gL8ssYiwmQywXGcu/MZaIRFhPF4DGcz0Bg7jsNoNIL3GfgG0MqyTOq++KVI05T1eg2waKVpaoUBjDEYY+LaPjeJGxG7wsaY6t//YYWTJKngd6XUsjHOsoz9fl/Bn42Pnec52+0WYFnBRjjPc8IwBHhVSi3+zV3FRVFUcKWUejzPX8Wr1aqCo0v5WhwEAUBcB6HmMgiCgLIsUUp1a491qfJms6EsS4Cr8BPe7XacTido+HL8xcYYjscjwKjpk3MjIkRRxOFwAHhUSq2aQIB2HMcVXCilXptCgHaSJBVc2kAAqivlK/EH0qWTL9ZN1TQAAAAASUVORK5CYII=) no-repeat left center;
	float:right;
	position:relative;
	top:5px; right:6px;
}
.dhx_el_prevbutton input {
	border-top-left-radius: 0px;
	border-bottom-left-radius: 0px;
	-webkit-border-top-left-radius: 0px;
	-webkit-border-bottom-left-radius: 0px;
	border-left-width:0px;
}
.dhx_el_prevbutton .dhx_el_arrow{
	background:url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAA8AAAAiCAYAAACA5IOiAAABrklEQVRIiZ3UX04TURTH8W9x7mCLCKIoTklL7dAOhYq2EI3GHdSHbqLLgLgMVnEeuo66AUOCJFMCxoREouXFy8vMWDKtndObzNPcz+/+OSc3xxxDRHrASW4O2AIGACosIh4QbnibbO80WFAuHD5aXsYPdrDW4ihWDY3rsn/wDmstQDYsIn3AO/zwKYGZsIicAJ32+4/34EwsIkdAr77bxLhuCk+97biWFb/G85fexDkTsYh0gH6xVKZY2pq6sxSOa7n+YoMtvzYVwuQzhytP1ihXt1Nn/C8WkdAYFz9ozIT3sIgMAK/ZPswEExzVsrX39iAzBHDiWtZ2mzjG6DDwZbNcIV9YUsFk2xaLtX9VEGABOA6/n/Hz6hJrrerLQXJhvVLV5/HKauaVkw6LA17VA/KFJR2OAvpAp1ILyBcKOhwFDICW39jDGKPD4wHB6zd6HAWEgFdv7utxFGAfOA7VoKHHccDiwzylqp/6l+XdLt6O/nB++i3VJDNxt9sdAu3b0Yjh+ZkORwFfgfbvmxuuLkIdHgv4/Ov6mh8Xw3+9rRnxk7z69JkejwfMY+OAozvRWOTT6eivNwAAAABJRU5ErkJggg==) no-repeat left center;
	float:left;
	position:relative;
	top:5px; left:9px;
}
.dhx_touch.dhx_el_nextbutton .dhx_el_arrow{
	background:url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAA8AAAAiCAYAAACA5IOiAAABrklEQVRIiZ3UMW7iQBTG8X/QuoHCFFCQSIAEhUWDlHCMpHiXCLfYaPcW4RKvSG4RJZUpXGAJWRuMhJBMYQoseYvNRCzE4MmTRi5GP3+jeU+Dquaqes83qvLxfVTVa2s8Go1oNBoAr6p6aZ3c7XapVqsAf6wxwGAwwHEcVPXVGgMMh0OAa1V9KoXzPGd/eZ4HcKuqj1bJALVajV6vB3B/roVHGKBer9Nut+FfC2+tMECz2TQtfCqagUIM0Ol0cF0XCmbgJAbo9/tmBl6O8OFtf7U8z8NxnMvDGTibbOqjhf/NQGnsOM7+DPwEuJjP53nZHwAkScJsNgMYl0425bourVYL4OFHnlsFA2CMdfJisSCOY4BfVni1Whn4ICKT0jhJEqIoMvA3lDx2mqaEYQgwMbAUTtOUIAgAnkVkvL938rZ3u52BbyJyd7h/Mnk6nRp489V+IfZ9H+C9CBZi3/fJsgwRuTp1siMcBAFZlgGchEc4DEO22y3AlYi8n8Oftx1FEZvNBuCmDPxMjqKI9XoNcCcib2UgQCWOYwPHIvJcFgJUlsulgRMbCIB5Ur5TfwFCp9SHbIQuDAAAAABJRU5ErkJggg==) no-repeat left center;
}
.dhx_touch.dhx_el_prevbutton .dhx_el_arrow{
	background:url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAA8AAAAiCAYAAACA5IOiAAABf0lEQVRIiZ2VXU7CQBSFP6iKCimhUoEC/sYNyDbwYTaBu9C4DNzEfXAdsAWjsYBiNBIxVIP60hK0hTK9jzP9zpnecyeTIkGJSAtopxKAp0AHQAsWEQdws6aJZZdIaxq765kMll0CWB0WETdtGJRre7O1lWARuQGc6sHRn/VYWETaQNPZPwztLYVF5AJoFcsVjLW10P7CbgdZFuxdcmY+8ptIWESawI1ZsMhbOwtPFoL/Z7msov7Z3dzOxoIhOMjSrjix4B9YRDpEZBkL+1meRmW5FA6yLNXqkVnGOV8V7F02MptaYAAnrjRw+Tp84n30pg2nYNawVrFcYSub03JGKXUOXD8P+nx6Ez3noPx72yzV6is1MGq2O/iZx0UX6rZSqgF0e3e3+s5zJ3ABp358og/7Aj9pw2DRvC8dEqVU6ns6ZfBwrw/7Vf3yvEiBWFgp1QMaX57HsN/TdkYp1QUak48xL8NHPXhO4Gw8Gs0EkrySLaBtFix9eF4gCRsIXPwCRM6BFTw+3/oAAAAASUVORK5CYII=) no-repeat left center;
}
.dhx_touch.dhx_el_button input, .dhx_touch.dhx_el_bigbutton input, .dhx_touch.dhx_el_prevbutton input, .dhx_touch.dhx_el_nextbutton input{
	background-color: #dedede;background: -o-linear-gradient(top, #e4e4e4 0% ,  #dedede 100%);background: -ms-linear-gradient(top, #e4e4e4 0% ,  #dedede 100%);background: -moz-linear-gradient(top, #e4e4e4 0% ,  #dedede 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#e4e4e4), color-stop(1,  #dedede));;
}
.dhx_touch.dhx_el_roundbutton input {
	background-color: #4f899d;background: -o-linear-gradient(top, #6799aa 0% ,  #4f899d 100%);background: -ms-linear-gradient(top, #6799aa 0% ,  #4f899d 100%);background: -moz-linear-gradient(top, #6799aa 0% ,  #4f899d 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#6799aa), color-stop(1,  #4f899d));
}
.dhx_el_bigroundbutton input, .dhx_el_bigbutton input{
	text-shadow: 0px 1px 0px #ffffff;
	background-color: #dedede;background: -o-linear-gradient(top, #fcfcfc 0% ,  #dedede 100%);background: -ms-linear-gradient(top, #fcfcfc 0% ,  #dedede 100%);background: -moz-linear-gradient(top, #fcfcfc 0% ,  #dedede 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#fcfcfc), color-stop(1,  #dedede));;
	height: 46px;
	line-height: 46px;
	font-size: 20px;
	border-radius: 22px;-webkit-border-radius:22px; -moz-border-radius:22px;;
	border: 1px solid #b0b0b0;
	color:#6d6d6d;
	font-weight:bold;
}
.dhx_el_roundbutton input, .dhx_el_bigroundbutton input{
	background-color:#6799aa;background: -o-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -ms-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -moz-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#9cbcc6), color-stop(30%, #80aab8), color-stop(60%,#6799aa), color-stop(100%, #4f899d));;
	color: #ffffff;
	text-shadow: 0px -1px 0px rgba(0, 0, 0, 0.6);

	border-radius: 22px;-webkit-border-radius:22px; -moz-border-radius:22px;;
	
	text-shadow: 0px -1px 0px rgba(0, 0, 0, 0.6);
	-moz-box-shadow: inset 0px 1px 1px #b9d3dc, 0px 1px  #b9d3dc;-webkit-box-shadow: inset 0px 1px 1px #b9d3dc, 0px 1px  #b9d3dc;
}
.dhx_el_icon div{
	background-image:url(./imgs/bar_icons_sprite.png);
	background-repeat:no-repeat;
	width:22px; height:22px;
	margin:10px;
}
.dhx_el_imagebutton span {
	line-height: 		42px;
    font-size: 		20px;
}
.dhx_el_imagebutton img {
	vertical-align: middle;
    margin-top: -4px;
}
.dhx_all_segments{
	margin:5px;
	border-radius:0px;
	border-radius: 4px;-webkit-border-radius:4px; -moz-border-radius:4px;
	

	border: 1px solid #588a9b;
	-o-box-shadow:   0px  1px  1px #ebebeb;-ms-box-shadow:   0px  1px  1px #ebebeb;-moz-box-shadow:   0px  1px  1px #ebebeb;-webkit-box-shadow:   0px  1px  1px #ebebeb;

	display:inline-block;
	width:auto;
	white-space:nowrap;
}
.dhx_el_segmented .segment_0, .dhx_el_segmented .segment_1, .dhx_el_segmented .segment_N{
	background-color: #dedede;background: -o-linear-gradient(top, #fcfcfc 0% ,  #dedede 100%);background: -ms-linear-gradient(top, #fcfcfc 0% ,  #dedede 100%);background: -moz-linear-gradient(top, #fcfcfc 0% ,  #dedede 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#fcfcfc), color-stop(1,  #dedede));;
}
.dhx_el_segmented .selected.segment_0 , .dhx_el_segmented .selected.segment_1, .dhx_el_segmented .selected.segment_N{
	background-color:#6799aa;background: -o-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -ms-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -moz-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#9cbcc6), color-stop(30%, #80aab8), color-stop(60%,#6799aa), color-stop(100%, #4f899d));;
	color: #ffffff;
	text-shadow: 0px -1px 0px rgba(0, 0, 0, 0.6);
    -o-box-shadow: inset 0px 1px 1px #b9d3dc;-ms-box-shadow: inset 0px 1px 1px #b9d3dc;-moz-box-shadow: inset 0px 1px 1px #b9d3dc;-webkit-box-shadow: inset 0px 1px 1px #b9d3dc;
}
.dhx_all_segments div{
	padding:0 12px;
	text-shadow: 0px 1px 0px #ffffff;
	display:inline-block;
	color: #757575;
	font-weight: bold;
	font-size: 14px;
	text-align: center;
	line-height: 30px;
	cursor:pointer;
}
.dhx_all_segments div.selected {
	color: #ffffff;
	text-shadow: 0px -1px 0px rgba(0, 0, 0, 0.6);
}
.dhx_el_segmented .segment_0, .dhx_el_segmented .selected.segment_0{
	border-radius:0;border-top-left-radius: 4px; border-bottom-left-radius: 4px;-webkit-border-radius:0;-moz-border-radius:0;-webkit-border-top-left-radius: 4px; -webkit-border-bottom-left-radius: 4px; -moz-border-radius-topleft: 4px; -moz-border-radius-bottomleft: 4px;
	padding-left: 16px;
}
.dhx_all_segments .segment_1{
	border-left:1px solid #b0b0b0;
}
.dhx_all_segments .segment_N{
	border-radius:0;border-top-right-radius: 4px; border-bottom-right-radius: 4px;-webkit-border-radius:0;-moz-border-radius:0;-webkit-border-top-right-radius: 4px; -webkit-border-bottom-right-radius: 4px; -moz-border-radius-topright: 4px; -moz-border-radius-bottomright: 4px;
    padding-right: 15px;
	border-left:1px solid #b0b0b0;
}
.dhx_inp_radio_on.dhx_hidden, .dhx_inp_checkbox_on.dhx_hidden{
	display:none;
}
.dhx_radio{
	line-height:32px;
	padding: 5px 0 0 5px;
	float:left;
}
.dhx_inp_radio_border {
	margin-right:1px;
	width: 	22px;
	height: 	22px;
    margin-top: 6px;
	border: 	1px solid #b0b0b0;
	background-color: #ffffff;
	border-radius: 20px;-webkit-border-radius:20px; -moz-border-radius:20px;
	text-align: center;
	cursor: pointer;
	float: left;
}
.dhx_inp_radio_on {
	width: 	12px;
	height: 12px;
	border: none;
	background-color: #4f899d;

	cursor: pointer;
	margin: 5px;
	padding: 0px;
	display: block;

	border-radius: 10px;-webkit-border-radius:10px; -moz-border-radius:10px;
	-webkit-appearance: none;
}
.dhx_el_box, .dhx_el_box input, .dhx_input_box{
	font-size:  18px;
	height: 	31px;
    line-height:31px;
    vertical-align:middle;
}
.dhx_el_box, .dhx_input_box{
	margin:  5px;
	padding: 0px 8px;
	border-radius: 8px;-webkit-border-radius:8px; -moz-border-radius:8px;
	background-color:#FFFFFF;background: -o-linear-gradient(top, #f2f2f2 0% , #FFFFFF 100%);background: -ms-linear-gradient(top, #f2f2f2 0% , #FFFFFF 100%);background: -moz-linear-gradient(top, #f2f2f2 0% , #FFFFFF 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#f2f2f2), color-stop(1, #FFFFFF));;
	border: 	1px solid 	#adadad;
}
.dhx_el_radio .dhx_el_box, .dhx_el_checkbox .dhx_el_box, .dhx_el_toggle .dhx_el_box, .dhx_el_counter .dhx_el_box{
	padding: 0px;
	background:transparent;
	border:none;
}
.dhx_el_box label{
	color: #6a6a6a
}
.dhx_inp_list, .dhx_inp_text, .dhx_inp_combo {
	float: left;
	background-color:#FFFFFF;background: -o-linear-gradient(top, #f2f2f2 0% , #FFFFFF 100%);background: -ms-linear-gradient(top, #f2f2f2 0% , #FFFFFF 100%);background: -moz-linear-gradient(top, #f2f2f2 0% , #FFFFFF 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#f2f2f2), color-stop(1, #FFFFFF));;
	border: none;
	padding: 0px;
	height: 	31px;
	line-height: 31px;
	vertical-align:middle;
}
.dhx_el_box .dhx_inp_text, .dhx_el_input .dhx_input_box{
	line-height:normal;
}
label.dhx_inp_label{
	line-height: 31px;
	display:block;
	float: left;
	overflow: hidden;
}
.dhx_inp_toggle_left_on, .dhx_inp_toggle_left_off, .dhx_inp_toggle_right_on, .dhx_inp_toggle_right_off {
	height: 32px;
    line-height: 32px;
	border: none;

	cursor: pointer;
	display: block;
	float: left;

	margin: 0;
	text-align: center;
	background-color: #dedede;background: -o-linear-gradient(top, #fcfcfc 0% ,  #dedede 100%);background: -ms-linear-gradient(top, #fcfcfc 0% ,  #dedede 100%);background: -moz-linear-gradient(top, #fcfcfc 0% ,  #dedede 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#fcfcfc), color-stop(1,  #dedede));;
	
	padding: 0 	14px;
}
.dhx_inp_toggle_left_on, .dhx_inp_toggle_right_on{
	color: #ffffff;
	text-shadow: 0px -1px 0px rgba(0, 0, 0, 0.6);
	background-color:#6799aa;background: -o-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -ms-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -moz-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#9cbcc6), color-stop(30%, #80aab8), color-stop(60%,#6799aa), color-stop(100%, #4f899d));;
	-o-box-shadow: inset 0px -1px 1px #b9d3dc;-ms-box-shadow: inset 0px -1px 1px #b9d3dc;-moz-box-shadow: inset 0px -1px 1px #b9d3dc;-webkit-box-shadow: inset 0px -1px 1px #b9d3dc;

	border: 1px solid #afafaf;
}
.dhx_inp_toggle_left_off, .dhx_inp_toggle_right_off {
	color:  #6a6a6a;
	background-color: #dedede;background: -o-linear-gradient(top, #fcfcfc 0% ,  #dedede 100%);background: -ms-linear-gradient(top, #fcfcfc 0% ,  #dedede 100%);background: -moz-linear-gradient(top, #fcfcfc 0% ,  #dedede 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#fcfcfc), color-stop(1,  #dedede));;
	
	border: 1px solid #afafaf;
	-o-box-shadow:  1px 0px 0px #bee2ee;-ms-box-shadow:  1px 0px 0px #bee2ee;-moz-box-shadow:  1px 0px 0px #bee2ee;-webkit-box-shadow:  1px 0px 0px #bee2ee;
}
.dhx_inp_toggle_left_on, .dhx_inp_toggle_left_off{
	border-radius:0;border-top-left-radius: 4px; border-bottom-left-radius: 4px;-webkit-border-radius:0;-moz-border-radius:0;-webkit-border-top-left-radius: 4px; -webkit-border-bottom-left-radius: 4px; -moz-border-radius-topleft: 4px; -moz-border-radius-bottomleft: 4px;
}
.dhx_inp_toggle_right_on, .dhx_inp_toggle_right_off{
	border-radius:0;border-top-right-radius: 4px; border-bottom-right-radius: 4px;-webkit-border-radius:0;-moz-border-radius:0;-webkit-border-top-right-radius: 4px; -webkit-border-bottom-right-radius: 4px; -moz-border-radius-topright: 4px; -moz-border-radius-bottomright: 4px;
}
.dhx_list_icon, .dhx_calendar_icon{
	display: block;
	float: left;
	background-repeat:no-repeat;
}
.dhx_list_icon{
	margin-top: 12px;
	width: 11px !important;
	height:10px;
	margin-left:4px;
	background-image: url(./imgs/images.png);
	background-repeat:no-repeat;
	background-position: 0 -56px;
}
.dhx_calendar_icon{
	margin-top: 9px;
	height:13px;
    background-image:url(./imgs/images.png);
	background-position: 0px -78px;
	background-repeat:no-repeat;
}
.dhx_inp_toggle_right_off{
	border-left:0px;
}
input.dhx_inp_counter_prev, input.dhx_inp_counter_next{
	width: 		37px;
	height: 	33px;
	background-repeat: no-repeat;
	background-color: transparent;
	cursor: pointer;
	float: left;

	background-color:#6799aa;background: -o-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -ms-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -moz-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#9cbcc6), color-stop(30%, #80aab8), color-stop(60%,#6799aa), color-stop(100%, #4f899d));;
	color: #ffffff;
	text-shadow: 0px -1px 0px rgba(0, 0, 0, 0.6);

	border: 1px solid #afafaf;
	
	font-size:		26px;
	padding-left:	8px;
	line-height:	26px;
	 font-family:Tahoma;
}
input.dhx_inp_counter_prev{
	font-size:16px;
	font-weight:bold;
	line-height: 10px;
	padding:0px;
}
.dhx_inp_counter_prev {
	border-radius:0px;
	border-radius:0;border-top-left-radius: 4px; border-bottom-left-radius: 4px;-webkit-border-radius:0;-moz-border-radius:0;-webkit-border-top-left-radius: 4px; -webkit-border-bottom-left-radius: 4px; -moz-border-radius-topleft: 4px; -moz-border-radius-bottomleft: 4px;
}
.dhx_inp_counter_next {
	border-radius:0px;
	border-radius:0;border-top-right-radius: 4px; border-bottom-right-radius: 4px;-webkit-border-radius:0;-moz-border-radius:0;-webkit-border-top-right-radius: 4px; -webkit-border-bottom-right-radius: 4px; -moz-border-radius-topright: 4px; -moz-border-radius-bottomright: 4px;
}
.dhx_inp_counter_value {
	width: 	20px;
	height: 	23px;
	border-top: 1px solid #afafaf;
	float: left;
	text-align: center;
	padding: 4px 8px;
	overflow: 						hidden;
	line-height: 		24px;
}
.dhx_inp_counter_prev, .dhx_inp_counter_next,.dhx_inp_counter_value {
	-moz-box-shadow: inset 0px 1px 1px #b9d3dc, 0px 1px #ebebeb;-webkit-box-shadow: inset 0px 1px 1px #b9d3dc, 0px 1px #ebebeb;
	border-bottom:1px solid #afafaf;
}
.dhx_inp_counter_label, .dhx_inp_toggle_label {
	float: left;
	padding: 6px 10px;
	color: 	#6a6a6a;
	line-height: 24px;
}
.dhx_inp_checkbox_border {
	width: 		24px;
	height: 	24px;
	padding: 0;
    margin-top: 5px;

	border: 	1px solid #b0b0b0;
	background-color: #ffffff;
	border-radius: 5px;-webkit-border-radius:5px; -moz-border-radius:5px;
	
	text-align: center;
	cursor: pointer;
	float: left;
}
input.dhx_inp_checkbox_on {
	display: block;
	width: 18px;
	height: 18px;
	border: none;
	
	cursor: pointer;
	margin: 3px 0 0 3px;
	padding: 0;
	line-height:14px;
	font-size:14px;
	font-weight:bold;

	color: #ffffff;
	text-shadow: 0px -1px 0px rgba(0, 0, 0, 0.6);
	background-color: #4f899d;
	border-radius: 3px;-webkit-border-radius:3px; -moz-border-radius:3px;
	-webkit-appearance: none;
}
.dhx_inp_checkbox_label, .dhx_inp_radio_label {
	float: left;
	padding: 0 10px;
	cursor: pointer;
    height:	35px;
    line-height: 35px;
    font-size:18px;
    color: #6a6a6a;
}
.dhx_el_textarea textarea{
	margin: 5px;
	border-radius: 8px;-webkit-border-radius:8px; -moz-border-radius:8px;
	font-size: 18px;
	background-color:#fefefe;background: -o-linear-gradient(top, #f7f7f7 0% , #fefefe 100%);background: -ms-linear-gradient(top, #f7f7f7 0% , #fefefe 100%);background: -moz-linear-gradient(top, #f7f7f7 0% , #fefefe 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#f7f7f7), color-stop(1, #fefefe));
	border: 	1px solid #b0b0b0;
}
.dhx_el_tabbar {
	height: 49px;
	vertical-align:top;
	color:#6d6d6d;
}
.dhx_el_tabbar div {
	display: inline-block;
	text-align:center;
	cursor: pointer;
	height: 46px;
    margin: 1px 2px;
}
.dhx_el_tabbar .selected {
	border-radius: 4px;-webkit-border-radius:4px; -moz-border-radius:4px;
    background-color: #4f899d;background: -o-linear-gradient(top, #9cbcc6 0% ,  #4f899d 100%);background: -ms-linear-gradient(top, #9cbcc6 0% ,  #4f899d 100%);background: -moz-linear-gradient(top, #9cbcc6 0% ,  #4f899d 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#9cbcc6), color-stop(1,  #4f899d));;
}
.dhx_el_tabbar img{
	vertical-align: middle;
}
.dhx_el_tabbar span{
	color:#444;
	margin-top: 1px;
    line-height: 12px;
    padding: 0 10px 2px;
    font-weight:normal;
    font-size: 10px;
    text-shadow: none;
    display: block;
}
.dhx_el_tabbar .selected span{
	font-weight:bold;
	color: #ffffff;
	text-shadow: 0px -1px 0px rgba(0, 0, 0, 0.6);
}
.invalid .dhx_inp_label, .invalid input, .invalid textarea{
	color:#FF0000;
}
.dhx_mainbar{
	background-color:#e0eaed;background: -o-linear-gradient(top, #ffffff 0% , #e0eaed 50% , #cadce1 100%);background: -ms-linear-gradient(top, #ffffff 0% , #e0eaed 50% , #cadce1 100%);background:  -moz-linear-gradient(top, #ffffff 0% , #e0eaed 50% , #cadce1 100%);background:  -webkit-gradient(linear, left top, left bottom, color-stop(0,#ffffff), color-stop(0.5,#e0eaed), color-stop(1, #cadce1));
	font-size:18px;
	font-weight:bold;
	color: #757575;
	text-shadow:    0px 1px 0px #ffffff;
}
.dhx_subbar{
	background-color:#e8e8e8;background: -o-linear-gradient(top, #ffffff 0% , #e8e8e8 50% , #c2c2c2 100%);background: -ms-linear-gradient(top, #ffffff 0% , #e8e8e8 50% , #c2c2c2 100%);background:  -moz-linear-gradient(top, #ffffff 0% , #e8e8e8 50% , #c2c2c2 100%);background:  -webkit-gradient(linear, left top, left bottom, color-stop(0,#ffffff), color-stop(0.5,#e8e8e8), color-stop(1, #c2c2c2));
	font-size:18px;
	font-weight:bold;
	color: #757575;
	text-shadow:    0px 1px 0px #ffffff;
}
.dhx_bottombar{
	background-color:#cadce1;background: -o-linear-gradient(top, #ffffff 0% , #cadce1 100%);background: -ms-linear-gradient(top, #ffffff 0% , #cadce1 100%);background: -moz-linear-gradient(top, #ffffff 0% , #cadce1 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#ffffff), color-stop(1, #cadce1));
}
.dhx_toolbar .dhx_view{
	background-color:transparent;
}
.dhx_toolbar.dhx_transparentbar{
	background: transparent !important;
}
.dhx_allow_selection{
	
}
.dhx_dataview_item{
	font-size:8pt;
	cursor:pointer;
	background-color:#ffffff;
	overflow:hidden;
	text-align:center;
}
.dhx_dataview_default_item, .dhx_dataview_default_item_selected{
	border-right:1px solid #d3d3d3;
	border-bottom:1px solid #d3d3d3;
}
.dhx_dataview_FreeSize_item_selected, .dhx_dataview_default_item_selected{
	background-color:#6799aa;background: -o-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -ms-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -moz-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#9cbcc6), color-stop(30%, #80aab8), color-stop(60%,#6799aa), color-stop(100%, #4f899d));;
	color: #ffffff;
	text-shadow: 0px -1px 0px rgba(0, 0, 0, 0.6);
}
.dhx_strong{
	font-weight:bold;
	display: block;
	padding-bottom: 6px;
}
.dhx_light{
	color:#6a6a6a;
}
.dhx_accordionitem_body{
	position:relative;
}
.dhx_accordionitem_header{
	border:1px solid #adadad;
	border-bottom-width:0;
	position:relative;
	
	background-color:#e8e8e8;background: -o-linear-gradient(top, #ffffff 0% , #e8e8e8 50% , #c2c2c2 100%);background: -ms-linear-gradient(top, #ffffff 0% , #e8e8e8 50% , #c2c2c2 100%);background:  -moz-linear-gradient(top, #ffffff 0% , #e8e8e8 50% , #c2c2c2 100%);background:  -webkit-gradient(linear, left top, left bottom, color-stop(0,#ffffff), color-stop(0.5,#e8e8e8), color-stop(1, #c2c2c2));
	font-size:18px;
	font-weight:bold;
	color: #757575;
	text-shadow:    0px 1px 0px #ffffff;

	cursor:pointer;
	overflow:hidden;
}
.dhx_accordionitem_header .dhx_accordionitem_label{
	float:left;
	height:100%;
}
.dhx_accordionitem_button{
	background-image: url(./imgs/images.png);
	background-repeat:no-repeat;
}
.dhx_accordionitem_header .dhx_accordionitem_button, .dhx_accordionitem_header_v .dhx_accordionitem_button{
	float:left;
	position:relative;
	height:10px;
	width:11px;

	background-position: 0 -56px;
	margin: 18px 7px 0;
}
.dhx_accordionitem_header .dhx_accordionitem_button.collapsed{
	background-position: 0 -44px;
}
.dhx_list_item{
	cursor:pointer;
	
	line-height:22px;
	font-weight: bold;
	font-size: 16px;
	border-bottom:1px solid #d3d3d3;

	white-space:nowrap;
	text-align:left;
}
.dhx_list__item_selected, .dhx_list_item_selected{
	background-color:#6799aa;background: -o-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -ms-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -moz-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#9cbcc6), color-stop(30%, #80aab8), color-stop(60%,#6799aa), color-stop(100%, #4f899d));;
	color: #ffffff;
	text-shadow: 0px -1px 0px rgba(0, 0, 0, 0.6);
}
.dhx_list_group{
	position:relative;
}
.dhx_list_group_back, .dhx_list_group_back_selected{
	position: relative;
    background-color: #dfdfdf;background: -o-linear-gradient(top, #fcfcfc 10% ,  #dfdfdf 94% ,  #cccccc 100%);background: -ms-linear-gradient(top, #fcfcfc 10% ,  #dfdfdf 94% ,  #cccccc 100%);background:  -moz-linear-gradient(top, #fcfcfc 10% ,  #dfdfdf 94% ,  #cccccc 100%);background:  -webkit-gradient(linear, left top, left bottom, color-stop( 0.1,#fcfcfc), color-stop( 0.94, #dfdfdf), color-stop( 1,  #cccccc));;
   	border-bottom: 0px solid #ffffff;
   	border-top: 1px solid #fcfcfc;
}
.dhx_arrow_icon {
	position: absolute;
	top: 50%;
	bottom: 50%;
	margin-top: -6px;
	right: 29px;
	width: 9px;
	height: 13px;
	background-image: url(./imgs/images.png);
	background-repeat:no-repeat;
}
.dhx_list_group .dhx_arrow_icon, .dhx_list_group_selected .dhx_arrow_icon{
	background-position: 0 -106px;
}
.dhx_list_group_back .dhx_arrow_icon, .dhx_list_group_back_selected .dhx_arrow_icon{
	background-position: 0 -92px;
}
.dhx_pagelist{
	position:relative;
}
.dhx_pagelist.hidden_scroll .dhx_scroll_x {
	background-color:transparent !important;
}
.dhx_pagelist.hidden_scroll .dhx_scroll_y {
	background-color:transparent !important;
}
.dhx_list_count{
	float:right;
	width: 25px;
	font-size:14px;
	text-align:center;
	margin-right:45px;
	border-radius: 4px;-webkit-border-radius:4px; -moz-border-radius:4px;
	background-color: #929292;
	color: #ffffff;
	box-shadow: 0 1px 0 #000000;
	text-shadow: 0px -1px 0px rgba(0, 0, 0, 0.6);
}
.dhx_unit_header{
	font-weight:bold;
	padding: 0 10px;
	background-color:#fcfcfc;background: -o-linear-gradient(top, #dfdfdf 0% , #fcfcfc 100%);background: -ms-linear-gradient(top, #dfdfdf 0% , #fcfcfc 100%);background: -moz-linear-gradient(top, #dfdfdf 0% , #fcfcfc 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#dfdfdf), color-stop(1, #fcfcfc));;
	text-shadow: 0 1px 0 rgba(255, 255, 255, 0.6);
	font-size: 16px;
	line-height: 19px;
	font-weight:bold;
	color: #3b6471;
	text-shadow:    0px 1px 0px #ffffff;
	-o-box-shadow: inset 0px -1px 0px #dedede;-ms-box-shadow: inset 0px -1px 0px #dedede;-moz-box-shadow: inset 0px -1px 0px #dedede;-webkit-box-shadow: inset 0px -1px 0px #dedede;;
	text-align:left;
}
.dhx_window{
	position:absolute;
	-o-box-shadow:  0px 0px 20px #868686;-ms-box-shadow:  0px 0px 20px #868686;-moz-box-shadow:  0px 0px 20px #868686;-webkit-box-shadow:  0px 0px 20px #868686;
}
.dhx_win_body{
	color: ;
	background-color:#ffffff;
	overflow:hidden;	
	text-align:center;
}
.dhx_window, .dhx_win_content, .dhx_win_body, .dhx_win_body > .dhx_view{
	border-radius: 6px;-webkit-border-radius:6px; -moz-border-radius:6px;
}
.dhx_win_body > .dhx_view .dhx_cal_month{
	border-radius:0;border-top-left-radius: 5px; border-top-right-radius: 5px;-webkit-border-radius:0;-moz-border-radius:0;-webkit-border-top-left-radius: 5px; -webkit-border-top-right-radius: 5px; -moz-border-radius-topleft: 5px; -moz-border-radius-topright: 5px;
}
.dhx_win_head{
	border-bottom: 1px solid #adadad;
	border-radius:0;border-top-left-radius: 5px; border-top-right-radius: 5px;-webkit-border-radius:0;-moz-border-radius:0;-webkit-border-top-left-radius: 5px; -webkit-border-top-right-radius: 5px; -moz-border-radius-topleft: 5px; -moz-border-radius-topright: 5px;
}
.dhx_alert_head{
	color: #ffffff;
	text-shadow: 0px -1px 0px black;
	font-weight: bold;
	font-size:22px;
	background-color: #565656;background: -o-linear-gradient(top, #696969 0% ,  #565656 100%);background: -ms-linear-gradient(top, #696969 0% ,  #565656 100%);background: -moz-linear-gradient(top, #696969 0% ,  #565656 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0,#696969), color-stop(1,  #565656));
	text-align:center;
	line-height:42px;
}
.dhx_win_content{
	height:auto;
    width:auto;
	overflow:hidden;
}
.dhx_modal{
	width: 100%;
	height: 100%;
	position: absolute;
	top: 0;
	left: 0;

	background-color: #000000;
	opacity: 0.2;
}
@media only screen and (min-device-width : 320px) and (max-device-width : 480px) {
	.dhx_modal{
	    height: 150%;
}
.dhx_alert_text{
	color: #565656;
	padding:10px;
}
.dhx_point_top, .dhx_point_right, .dhx_point_bottom, .dhx_point_left{
	position:absolute;
}
.dhx_point_top, .dhx_point_bottom {
	width:13px;
	height:7px;
}
.dhx_point_left, .dhx_point_right {
	width:7px;
	height:13px;
}
.dhx_point_top{
	background-image: url(./imgs/images.png);
	background-position: 0 -36px;
}
.dhx_point_bottom{
	background-image: url(./imgs/images.png);
	background-position: 0 0;
}
.dhx_point_right{
	background-image: url(./imgs/images.png);
	background-position: 0 -22px;
}
.dhx_point_left{
	background-image: url(./imgs/images.png);
	background-position: 0 -36px;
}
.dhx_form_float, .dhx_form_clear{
	float:left;

	width:_width;
	font-size: _bigger_text_size;
	padding: _float_padding;
	height:_float_height;
}
.dhx_form_float{
	text-align:center;
}
.dhx_form_row_delimiter, .dhx_form_clear{
	clear:both;
}
.dhx_view_video {
	
}
.dhx_grid_header{
	overflow: hidden;
	font-size:18px;
	font-weight:bold;
	color: #757575;
	text-shadow:    0px 1px 0px #ffffff;
	background-color:#e8e8e8;background: -o-linear-gradient(top, #ffffff 0% , #e8e8e8 50% , #c2c2c2 100%);background: -ms-linear-gradient(top, #ffffff 0% , #e8e8e8 50% , #c2c2c2 100%);background:  -moz-linear-gradient(top, #ffffff 0% , #e8e8e8 50% , #c2c2c2 100%);background:  -webkit-gradient(linear, left top, left bottom, color-stop(0,#ffffff), color-stop(0.5,#e8e8e8), color-stop(1, #c2c2c2));

	height: 42px;
	line-height: 42px;
	border-bottom: 1px solid #adadad;
}
.dhx_grid_data, .dhx_grid_body{
	overflow: hidden;
}
.dhx_grid_header div, .dhx_cell{
	box-sizing: border-box;
	-ms-box-sizing: border-box;
	-moz-box-sizing: border-box;
	-webkit-box-sizing: border-box;
}
.dhx_grid_header div{
	padding: 0px 10px;
	
	overflow: hidden;
	border-right: 1px solid #d3d3d3;
	position:relative;
	white-space:nowrap;
}
.dhx_grid_header .dhx_sort_desc, .dhx_grid_header .dhx_sort_asc{
	background-image: url(./imgs/images.png);
	background-repeat:no-repeat;
	cursor:pointer;

	width: 11px;
	height: 10px;
	top: 17px;

	z-index:3;
	position:absolute;
	border-right-width:0px;
}
.dhx_grid_header .dhx_sort_desc{
	background-position: 0 -56px;;
}
.dhx_grid_header .dhx_sort_asc{
	background-position: 0 -67px;
}
.dhx_grid_data{
	width:100%;
}
.dhx_grid_row, .dhx_grid_row_selected{
	border-bottom: 1px solid #d3d3d3;
	font-size:	18px;
	overflow: hidden;
	table-layout:fixed;
}
.dhx_grid_row_selected{
	background-color:#6799aa;background: -o-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -ms-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -moz-linear-gradient(top, #9cbcc6 0%,  #80aab8 30%, #6799aa 60%,  #4f899d 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#9cbcc6), color-stop(30%, #80aab8), color-stop(60%,#6799aa), color-stop(100%, #4f899d));;
	color: #ffffff;
	text-shadow: 0px -1px 0px rgba(0, 0, 0, 0.6);
}
.dhx_grid_row .dhx_cell, .dhx_grid_row_selected .dhx_cell{
	overflow:hidden;

	padding: 0px 10px;
	border-right: 1px solid #d3d3d3;
}
.dhx_carousel{
	position:relative;
}
.dhx_carousel_panel{
	position:absolute;
	background-color: transparent;
	border:0;
	width:auto;
	height:auto;
}
.dhx_carousel_panel .dhx_carousel_active, .dhx_carousel_panel .dhx_carousel_inactive{
	float:left;
	margin: 4px;
	height:8px;
	width:8px;
	border-radius: 8px;-webkit-border-radius:8px; -moz-border-radius:8px;
}
.dhx_carousel_active{
	background: #262626;background: -moz-radial-gradient(center 45deg, circle closest-corner, #5a97ac 0%, #262626 100%);background: -webkit-gradient(radial, center center, 1, center center, 4, from(#5a97ac), to(#262626));
}
.dhx_carousel_inactive{
	background: #858585;background: -moz-radial-gradient(center 45deg, circle closest-corner, #d0d0d0 0%, #858585 100%);background: -webkit-gradient(radial, center center, 1, center center, 4, from(#d0d0d0), to(#858585));
}
.dhx_scroll_carousel{
	position:relative;
}
.dhx_carousel .dhx_scroll_x {
	background-color:transparent !important;
}
.dhx_carousel .dhx_scroll_y {
	background-color:transparent !important;
}
.dhx_notice{
	font-family: "Helvetica World", "HelveticaNeue", "Helvetica Neue", "HelveticaNeueRoman", "Helvetica", "Tahoma", "Geneva", "Arial", sans-serif;
	
	color:#303030;
	background-color: #303030;
	opacity:0.8;
	border-radius: 10px;-webkit-border-radius:10px; -moz-border-radius:10px;
	
	position:absolute;
	text-align: center;
	font-weight:bold;
	font-size: 20px;

	min-width:302px;
	border:2px solid white;

	-o-box-shadow:  0px 0px  8px #000;-ms-box-shadow:  0px 0px  8px #000;-moz-box-shadow:  0px 0px  8px #000;-webkit-box-shadow:  0px 0px  8px #000;
}
.dhx_notice_content{
	display:block;
	margin:19px 20px;
	color:#ffffff;
}
.dhx_chart{
	position:relative;
	font-size:13px;
	color:#303030;
}
.dhx_canvas_text{
	position:absolute;
	text-align:center;
	overflow:hidden;	
	white-space:nowrap;
}
.dhx_map_img{
	width : 100%;
	height : 100%;
	position : absolute;
	top : 0px;
	left : 0px;
	border:0px;
	filter:alpha(opacity=0);
}
.dhx_axis_item_y{
	position:absolute;
	height:11px;
	line-height:11px;
	text-align:right;
}
.dhx_axis_item_x{
	
}
.dhx_axis_title_x{
	text-align:center;
}
.dhx_axis_title_y{
	text-align:		center;
	
	-webkit-transform: rotate( 		-90deg );
    
	-moz-transform: rotate( 		-90deg );
    
	filter: progid:DXImageTransform.Microsoft.BasicImage(rotation= 	3 );
    
	-o-transform:rotate( 		-90deg );
	padding-left: 3px;
}
.dhx_chart_legend{
	position:absolute;
}
.dhx_chart_legend_item{
	height:	18px;
	line-height:	18px;
	padding: 	2px;
}
.dhx_tooltip{
	display:none;
	position:absolute;
	font-family: _font_family;
	font-size:_text_size_pts;
	z-index:10000;
	background-color:;
	padding:2px;
	border:1px solid _item_border_color;
}
.dhx_el_slider{
	position:relative;
	float:left;
}
.dhx_slider_bar{
	position:absolute;
	top:20px; left:5px;
	height:8px;
	width:500px;
	height:8px;
	background-color:yellow;
	
	background: -moz-linear-gradient(left,#48b82d, #ecf005 30%,#e7260f ) no-repeat; 
	background: -webkit-gradient(linear, left top, right top, from(#48b82d),color-stop(0.30,#ecf005),to(#e7260f)) no-repeat; 
	background: -webkit-linear-gradient(left,#48b82d, #ecf005 30%, #e7260f) no-repeat;
	background: -o-linear-gradient(left, #48b82d , #ecf005 30%, #e7260f) no-repeat; 
	-moz-box-shadow: inset 0px 1px 2px 2px rgba(0,0,0,0.2);
	-webkit-box-shadow: inset 0px 1px 2px 2px rgba(0,0,0,0.2);
	box-shadow: inset 0px 1px 2px 2px rgba(0,0,0,0.2);
}
.dhx_slider_bar_empty{
	position:absolute;
	top:20px; left:205px;
    height:8px;
	width:300px;
	background-color:white;
}
.dhx_slider_bar, .dhx_slider_bar_empty{
	-webkit-border-radius: 4px;
	-moz-border-radius: 4px;
	border-radius: 4px;
	-moz-box-shadow: inset 0px 1px 3px 2px rgba(0,0,0,0.2);
	-webkit-box-shadow: inset 0px 1px 3px 2px rgba(0,0,0,0.2);
	box-shadow: inset 0px 1px 3px 2px rgba(0,0,0,0.2);
}
.dhx_slider_handle{
	position:absolute;
	top:12px; left:200px;
	width:20px; height:20px; 

	cursor:pointer;
	border-radius: 11px;
	-moz-border-radius: 11px;
	-webkit-border-radius:11px;
	background-color: #e2e2e2;
	border:1px solid #c1c1c1;
	border-bottom:1px solid #9e9e9e;
	
	background: -moz-linear-gradient(top,#cdcdcd, #dddddd 20%,#f3f3f3 65%, #fcfcfc) no-repeat; 
	background: -webkit-gradient(linear, left top, left bottom, from(#cdcdcd),color-stop(0.2,#dddddd),color-stop(0.65, #f3f3f3), to(#f6f6f6)) no-repeat; 
	background: -webkit-linear-gradient(top, #cdcdcd, #dddddd 20%,#f3f3f3 65%, #fcfcfc) no-repeat;
	background: -o-linear-gradient(top, #cdcdcd, #dddddd 20%,#f3f3f3 65%, #fcfcfc) no-repeat;
	-moz-box-shadow: inset 0px 1px #fcfcfc;
	-webkit-box-shadow: inset 0px 1px #fcfcfc;
	box-shadow: iinset 0px 1px #fcfcfc;
}
.dhx_slider_line{
	position:absolute;
	top:16px; 
	left:45px;
	width:2px;
	height:16px; 
	border-radius: 2px;
	-moz-border-radius: 2px;
	-webkit-border-radius:11px;
	background-color:#a5a5a5;
	border:1px solid rgba(131,133,135,0.6);
	-moz-box-shadow: 1px 0px 1px rgba(156,162,168,0.5);
	-webkit-box-shadow: 1px 0px 1px rgba(156,162,168,0.5);
	box-shadow: 1px 0px 1px rgba(156,162,168,0.5);
}
.dhx_slider_title{
	width:100%;
	font-size:smaller;
	text-align:center;
	padding-top:4px;
}
.dhx_slider_label{
	float:left;
	padding:14px 10px;
}
.dhx_resize_area{
	position: absolute;
	top:0px; left:0px;
	width:100%;
	height:100%;
	z-index:1;
}
.dhx_resize_area.dhx_dir_x{
	cursor: e-resize;
}
.dhx_resize_area.dhx_dir_y{
	cursor: n-resize;
}
.dhx_resize_handle_x{
	cursor: e-resize;
	width:1px; height:100%;
	border:1px dotted #848484;
	position:absolute;
	top:-1px;
	left:150px;
	z-index:100;
}
.dhx_resize_origin_x{
	width:3px; height:100%;
	background-color:#c2c2c2;
	position:absolute;
	top:-1px;
	left:100px;
	z-index:100;
    cursor: e-resize;
}
.dhx_resize_handle_y{
	cursor: n-resize;
	height:1px; width:100%;
	border:1px dotted #848484;
	position:absolute;
	left:-1px;
	top:150px;
	z-index:100;
}
.dhx_resize_origin_y{
	cursor: n-resize;
	height:3px; width:100%;
	background-color:#c2c2c2;
	position:absolute;
	left:-1px;
	top:100px;
	z-index:100;
}
.dhx_resizer_y{
	cursor: n-resize;
    background-color: #ffffff;background: -o-linear-gradient(top, #E8E8E8 0% ,  #ffffff 50% ,  #d0d0d0 100%);background: -ms-linear-gradient(top, #E8E8E8 0% ,  #ffffff 50% ,  #d0d0d0 100%);background:  -moz-linear-gradient(top, #E8E8E8 0% ,  #ffffff 50% ,  #d0d0d0 100%);background:  -webkit-gradient(linear, left top, left bottom, color-stop(0,#E8E8E8), color-stop(0.5, #ffffff), color-stop(1,  #d0d0d0));
}
.dhx_resizer_x{
	cursor: e-resize;
    background-color: #ffffff;background: -o-linear-gradient(left, #d9d9d9 0% ,  #ffffff 50% ,  #d9d9d9 100%);background: -ms-linear-gradient(left, #d9d9d9 0% ,  #ffffff 50% ,  #d9d9d9 100%);background: url(./imgs/arr_top.png),  -moz-linear-gradient(left, #d9d9d9 0% ,  #ffffff 50% ,  #d9d9d9 100%);background: url(./imgs/arr_top.png),  -webkit-gradient(linear, left top, right top, color-stop(0,#d9d9d9), color-stop(0.5, #ffffff), color-stop(1,  #d9d9d9));
background-repeat:no-repeat, repeat-x;
background-position:center 36px, 0;
}
.dhx_datecells .dhx_cell{
	border:1px solid #848484;
	border-width:0 1px 1px 0;
	text-align:center;
	font-weight:bold;
	padding: 7px 0px;
}
.dhx_datecells .dhx_cell.first_row{
	border-top:1px solid #848484;
}
.dhx_datecells .dhx_cell.first_column{
	border-left:1px solid #848484;
}
.dhx_datecells{
	margin-left:20px;
	margin-top:10px;
}
.dhx_el_rectext {
	display:inline-block;
	font-size:18px;
}
.dhx_el_rectext input {
	font-size: 18px;
	line-height: 28px;
}
.dhx_recurring .delete .dhx_inp_form_button{
	background: -webkit-gradient(linear, left top, left bottom, from(#cd7c7c), to(#931a1a));  
	background: -moz-linear-gradient(top,  #cd7c7c,  #931a1a); 
	border-top:1px solid #888;
	border-radius:6px;
	-moz-border-radius:6px;
	-webkit-border-radius:6px;
	border:1px solid #8f8f8f;
	color:#ffffff;
	-moz-box-shadow:0 1px 1px #e7b6b6 inset, 0 1px #EBEBEB; 
	-webkit-box-shadow:0 1px 1px #e7b6b6 inset, 0 1px #EBEBEB; 
	box-shadow:0 1px 1px #e7b6b6 inset, 0 1px #EBEBEB;
}
.dhx_recurring .endless_button .dhx_el_roundbutton input{
	border-radius:6px;
	-moz-border-radius:6px;
	-webkit-border-radius:6px;
}
.dhx_recurring .dhx_rounded .dhx_scroll_cont{
	margin:10px;
	border-radius: 10px;
	-webkit-border-radius:10px;
	-moz-border-radius:10px;
	border:1px solid #ADADAD;
	position:relative;
}
.dhx_recurring .dhx_rounded .dhx_scroll_cont > .dhx_list_item:first-child{
	-webkit-border-radius: 0px;
	-webkit-border-top-right-radius: 9px;
	-webkit-border-top-left-radius: 9px;
	-moz-border-radius: 0px;
	-moz-border-radius-topright: 9px;
	-moz-border-radius-topleft: 9px;
	border-radius: 0px;
	border-top-right-radius: 9px;
	border-top-left-radius: 9px;
}
.dhx_recurring .dhx_rounded .dhx_scroll_cont > .dhx_list_item:last-child{
	-webkit-border-radius: 0px;
	-webkit-border-bottom-right-radius: 9px;
	-webkit-border-bottom-left-radius: 9px;
	-moz-border-radius: 0px;
	-moz-border-radius-bottomright: 9px;
	-moz-border-radius-bottomleft: 9px;
	border-radius: 0px;
	border-bottom-right-radius: 9px;
	border-bottom-left-radius: 9px;
	border-bottom-width:0px;
}
.dhx_recurring .dhx_rounded .dhx_list_item{
	position:relative;
}
.dhx_recurring .dhx_list_item .dhx_arrow_icon{
	background-image: url(imgs/images.png);
 	background-position: 0 -677px; 
	right: 17px;
}
.rec_list .dhx_list__item_selected{
	background: -webkit-gradient(linear, left top, left bottom, from(#9dbcc7),to(#4f899d));  
	background: -moz-linear-gradient(top,  #9dbcc7,  #518a9e);
}
.dhx_recurring .dhx_rec_table .dhx_cal_day_num{
	border-color: #FCFCFC #CCCCCC #CCCCCC #FCFCFC;
	border-width: 0 1px 1px 0;
	font-weight: bold;
}
.dhx_accordionitem_header{
	border-top-width:1px !important;
	border-bottom-width:1px !important;
}
.dhx_recurring .dhx_el_label{
	font-size:19px;
}
.dhx_recurring .dhx_accordionitem_header .blured{
	color:#9c9c9c
}
.dhx_recurring .dhx_accordionitem_header .dhx_accordionitem_button.collapsed, .dhx_accordionitem_header .dhx_accordionitem_button{
	background-position:0px 0px;
	height: 27px;
	width: 27px;
}
.dhx_recurring .dhx_accordionitem_header .dhx_accordionitem_button{
	display:none;
}
.dhx_recurring .dhx_accordionitem_header .radio{
	margin-top:8px;
	margin-left:7px;
	height: 24px;
	width: 24px;
	border-radius:13px;
	-moz-border-radius:13px;
	-webkit-border-radius:13px;
	box-shadow: 0px 1px 1px 1px #e1e1e1;
	-moz-box-shadow: 0px 1px 1px 1px #e1e1e1;
	-webkit-box-shadow:0px 1px 1px 1px #e1e1e1;
	border:1px solid #cacaca;
	float:left;
}
.dhx_recurring .dhx_accordionitem_header .radio.blured{
	margin-top:12px;
}
.dhx_recurring .dhx_accordionitem_header .radio .on{
	margin: 6px 6px;
	height: 12px;
	width: 12px;
	border-radius:6px;
	-moz-border-radius:6px;
	-webkit-border-radius:6px;
	background: -moz-linear-gradient(center top , #A0BFC9, #4F899D);
	background: -webkit-gradient(linear, left top, left bottom, from(#A0BFC9), to(#4F899D));
}
.dhx_recurring .dhx_accordionitem_header .dhx_accordionitem_label .text{
	padding-left:7px;
	float:left;
}
.dhx_recurring .dhx_inp_radio_on{
	background-image: url(imgs_mobile/radio_on.png);
	background-position:-7px -7px;
}
.dhx_recurring .dhx_inp_counter_prev, .dhx_recurring .dhx_inp_counter_next{
	background: -webkit-gradient(linear, left top, left bottom, from(#9dbcc7),color-stop(0.4,#80a9b8),color-stop(0.6,#6799aa),to(#4f899d));  
	background: -moz-linear-gradient(top,  #9dbcc7,  #518a9e);
}