/*
This software is allowed to use under GPL or you need to obtain Commercial or Enterise License
to use it in non-GPL project. Please contact sales@dhtmlx.com for details
*/

.dhtmlx_message_area{
	position:fixed;
	right:5px;
	width:250px;
	z-index:1000;
}

.dhtmlx-info{
	min-width: 120px;
	padding:4px 4px 4px 20px;
	font-family:Tahoma;
	z-index: 10000;

	margin:5px;
	margin-bottom:10px;

	-webkit-transition: all .5s ease;
    -moz-transition: all .5s ease;
    -o-transition: all .5s ease;
    transition: all .5s ease;
}
.dhtmlx-info.hidden{
	height:0px;
	padding:0px;
	border-width:0px;
	margin:0px;
	overflow:hidden;
}

.dhtmlx_modal_box{
	overflow:hidden;
	display: inline-block;
	min-width: 300px;
	width: 300px;
	text-align: center;
	position:fixed;

	background-color: #fff;
	background:-webkit-linear-gradient(top, #ffffff 1%, #d0d0d0 99%);
	background:-moz-linear-gradient(top, #ffffff 1%, #d0d0d0 99%);
	box-shadow: 0px 0px 14px #888;

	font-family: Tahoma;

	z-index:20000;

	border-radius:6px;
	border: 1px solid #ffffff;
}

.dhtmlx_popup_title{
	border-top-left-radius:5px;
	border-top-right-radius:5px;

	border-width:0px;
	
	background:url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAAoCAMAAAAIaGBFAAAAhFBMVEVwcHBubm5sbGxqampoaGhmZmZlZWVjY2NhYWFfX19dXV1bW1taWlpYWFhWVlZUVFRSUlJRUVFPT09NTU1LS0tJSUlHR0dGRkZERERCQkJAQEA+Pj49PT09PT0+Pj5AQEBBQUFDQ0NERERGRkZHR0dJSUlKSkpMTExMTEw5OTk5OTk5OTkny8YEAAAAQklEQVQImQXBCRJCAAAAwKVSQqdyjSPXNP7/QLsIhA6OTiJnF7GrRCpzc/fw9PKW+/gqlCq1RqvTG/yMJrPF6m/bAVEhAxxnHG0oAAAAAElFTkSuQmCC);
	background-image: -webkit-linear-gradient(top, #707070 1%, #3d3d3d 70%, #4c4c4c 97%, #393939 97%);
	background-image: -moz-linear-gradient(top, #707070 1%, #3d3d3d 70%, #4c4c4c 97%, #393939 97%);
}

.dhtmlx-info, .dhtmlx_popup_button, .dhtmlx_button{
	user-select: none;
	-webkit-user-select: none;
	-moz-user-select:-moz-none;

	cursor:pointer;
}

.dhtmlx_popup_text{
	overflow:hidden;
}

.dhtmlx_popup_controls{
	border-radius:6px;
	padding:5px;
}

.dhtmlx_popup_button, .dhtmlx_button{
	height: 30px;
	line-height:30px;

	display: inline-block;
	margin: 0 5px;
	border-radius: 6px;

	color:#FFF;
}
.dhtmlx_popup_button{
	min-width: 120px;
}

div.dhx_modal_cover {
	background-color:#000;
	cursor:default;

	filter:alpha(opacity = 20);
	opacity: 0.2;

	position: fixed;
	z-index:19999;
	left: 0px;		top: 0px;
	width: 100%;	height: 100%;

	border: none;
	zoom: 1;
}

.dhtmlx-info img, .dhtmlx_modal_box img{
	float:left;
	margin-right:20px;
}

.dhtmlx-alert-error .dhtmlx_popup_title, .dhtmlx-confirm-error .dhtmlx_popup_title{
	background: url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAAsCAIAAAArRUU2AAAATklEQVR4nIWLuw2AMBBDjVuQiBT2oWbRDATrnB0KQOJoqPzRe3BrHI6dcBASYREKovtK6/6DsDOX+stN+3H1YX9ciRgnYq5EWYhS2dftBIuLT4JyIrPCAAAAAElFTkSuQmCC);
}
.dhtmlx-alert-error, .dhtmlx-confirm-error {
	border: 1px solid #ff0000;
}

/*Skin section*/
.dhtmlx_button, .dhtmlx_popup_button{
	box-shadow: 0px 0px 4px #888;
	border:1px solid #838383;
}
.dhtmlx_button input, .dhtmlx_popup_button div{
	border:1px solid #FFF;
	background:url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAAeCAMAAADaS4T1AAAAYFBMVEVwcHBtbW1ra2toaGhmZmZjY2NhYWFeXl5cXFxaWlpXV1dVVVVSUlJQUFBNTU1LS0tJSUlGRkZERERBQUE/Pz88PDw9PT0+Pj5AQEBCQkJDQ0NFRUVHR0dISEhKSkpMTEzqthaMAAAAMklEQVQImQXBhQ2AMAAAsOIMlwWH/8+kRSKVyRVKlVrQaHV6g9FktlhFm93hdLk9Xt8PIfgBvdUqyskAAAAASUVORK5CYII=);
	background-image: -webkit-linear-gradient(top, #707070 1%, #3d3d3d 70%, #4c4c4c 99%);
	background-image: -moz-linear-gradient(top, #707070 1%, #3d3d3d 70%, #4c4c4c 99%);

	border-radius:6px;
	font-size:15px;
	font-weight:normal; 
	-moz-box-sizing:content-box;
	box-sizing:content-box;

	color:#fff; padding:0px; margin:0px;
	vertical-align:top;

	height:28px;
	line-height:28px;
}

.dhtmlx_button input:focus, .dhtmlx_button input:active, .dhtmlx_popup_button div:active, .dhtmlx_popup_button div:focus{

	background:url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAAeCAMAAADaS4T1AAAAXVBMVEVwcHBubm5tbW1sbGxra2tpaWloaGhnZ2dmZmZlZWVjY2NiYmJhYWFgYGBfX19dXV1cXFxbW1taWlpZWVlXV1dWVlZVVVVUVFRTU1NRUVFQUFBPT09OTk5NTU1LS0tT9SY0AAAAMUlEQVQImQXBhQGAMAAAIGxnx2z9/00BiVQmVyhVakGj1ekNRpPZYhVtdofT5fZ4fT8hpwG05JjexgAAAABJRU5ErkJggg==);
	background-image: -webkit-linear-gradient(top, #707070 1%, #4c4c4c 99%);
	background-image: -moz-linear-gradient(top, #707070 1%, #4c4c4c 99%);	
}
.dhtmlx_popup_title{
	color:#fff;
	text-shadow: 1px 1px #000;
	height:40px; line-height:40px;
	font-size:20px;
}
.dhtmlx_popup_text{
	margin:15px 15px 5px 15px;
	font-size:14px;
	color:#000;
	min-height:30px;
	border-radius:6px;
}


.dhtmlx-info, .dhtmlx-error{
	font-size:14px;
	color:#000;
	box-shadow: 0px 0px 10px #888;
	
	padding:0px;
	
  	background-color:#FFF;
	border-radius:3px;
	border:1px solid #ffffff;
}
.dhtmlx-info div{
	padding:5px 10px 5px 10px;
	background-color: #fff;

	border-radius:3px;
	border:1px solid #B8B8B8;
}
.dhtmlx-error{
	background-color: #d81b1b;
	border:1px solid #ff3c3c;
	box-shadow: 0px 0px 10px #000;
}
.dhtmlx-error div{
	background-color: #d81b1b;	
	border:1px solid #940000;
	color:#FFF;
}


.dhx_cal_container{
	background-color:#C2D5FC;
	font-family:Tahoma; 
	font-size:8pt;
	position:relative;
	overflow:hidden;
}
.dhx_cal_container div{
	-moz-user-select:none;    
	-moz-user-select:-moz-none;    
}
.dhx_cal_navline{
	height:20px;
	position:absolute;
	z-index:3;
	width:750px;
	color:#2F3A48;
}
.dhx_cal_navline div{ 
	position:absolute;
	top:2px; 
	white-space:nowrap;
}
.dhx_cal_navline .dhx_cal_date {
	font-weight:600;
	left:210px;
	padding-top: 1px;
}
.dhx_cal_button .dhx_left_bg{
	width:1px; overflow:hidden;
	height:17px;
	z-index:20;
	top:0px;
}
.dhx_cal_prev_button{
	background-image:url(imgs/buttons.png);
	background-position:0px 0px;
	width:29px; height:17px;
	left:50px; cursor:pointer;
}
.dhx_cal_next_button{
	background-image:url(imgs/buttons.png);
	background-position: -30px 0px;
	width:29px; height:17px;
	left:80px; cursor:pointer;
}
.dhx_cal_today_button{
	background-image:url(imgs/buttons.png);
	background-position: -60px 0px;
	width:75px; height:17px;
	left:112px; cursor:pointer;
	text-align:center;
	text-decoration:underline;
}
.dhx_cal_tab{
	width:59px; height:19px;
	text-align:center;
	text-decoration:underline;
	padding-top:2px;
    cursor:pointer;
    background-color: #D8E1EA;

    -webkit-border-top-left-radius: 4px;
    -webkit-border-top-right-radius: 4px;
    -moz-border-radius-topleft: 4px;
    -moz-border-radius-topright: 4px;
    border-top-left-radius: 4px;
    border-top-right-radius: 4px;
}
.dhx_cal_tab.active{
	text-decoration:none;

    cursor:default;
	font-weight:bold;
    border: 1px dotted #586A7E;
    border-bottom: 0;
    background-color: #C2D5FC;
}
.dhx_cal_header{
	position:absolute;
	left:10px; 	top:23px;
	width:750px;
	border-top:1px dotted #8894A3;
	border-right:1px dotted #8894A3;
	z-index:2;
	overflow:hidden;
	color:#2F3A48;
}
.dhx_cal_data{
	border-top:1px dotted #8894A3;
	position:absolute;
	top:44px;
	width:600px;
	overflow-y:auto;
	overflow-x:hidden;
}
.dhx_scale_bar{
	position:absolute;	
	text-align:center;
	background-color:#C2D5FC;
	padding-top:3px;
	border-left:1px dotted #586A7E;
}
.dhx_scale_holder{
	position:absolute;	
	border-right:1px dotted #586A7E;
	background-image:url(imgs/databg.png);
}
.dhx_scale_holder_now{
	position:absolute;	
	border-right:1px dotted #586A7E;
	background-image:url(imgs/databg_now.png);
}
.dhx_scale_hour{
	height:41px;
	width:50px;
	border-bottom:1px dotted #8894A3;
	background-color:#C2D5FC;
	text-align:center;
	line-height:40px;
	color:#586A7E;
	overflow:hidden;
}
.dhx_month_head{
	background-color:#EBEFF4;
	color:#2F3A48;	
	border-right:1px dotted #586A7E;
	height:18px;
	padding-right:5px;
	padding-top:3px;
	text-align:right;
}
.dhx_month_body{
	border-right:1px dotted #586A7E;
	border-bottom:1px dotted #586A7E;
	background-color:#FFFFFF;
}
.dhx_now .dhx_month_body{
	background-color:#E2EDFF;
}
.dhx_after  .dhx_month_body, .dhx_before .dhx_month_body{
	background-color:#ECECEC;
}
.dhx_after  .dhx_month_head, .dhx_before .dhx_month_head{
	background-color:#E2E3E6;
	color:#94A6BB;
}
.dhx_now .dhx_month_head{
	background-color:#D1DEF4;
	font-weight:bold;
}
.dhx_cal_drag{
	position:absolute;
	z-index:9999;
	background-color:#FFE763;
	border:1px solid #B7A543;
	opacity:0.5;
	filter:alpha(opacity=50);
}
.dhx_loading{
	position:absolute;
	width:128px;
	height:15px;
	background-image:url(imgs/loading.gif);
	z-index:9999;
}
.dhx_multi_day_icon, .dhx_multi_day{
	background-color:#E1E6FF;
	background-repeat:no-repeat;
	border-right:1px dotted #8894A3;
}
.dhx_multi_day{
	position: absolute;
	border-top:1px dotted #8894A3;
}
.dhx_multi_day_icon, .dhx_multi_day_icon_small{
	background-position: center center;
	background-color:#E1E6FF;
	background-repeat:no-repeat;
	border-bottom:1px dotted #8894A3;
	border-right:1px dotted #8894A3;
}
.dhx_multi_day_icon{
	background-image:url(imgs/clock_big.gif);
}
.dhx_multi_day_icon_small{
	background-image:url(imgs/clock_small.gif);

}
.dhtmlxLayoutPolyContainer_dhx_skyblue 	.dhx_cal_container {
	background-color: #d0e5ff;
}
.dhx_cal_event .dhx_header, .dhx_cal_event .dhx_title, .dhx_cal_event .dhx_body, .dhx_cal_event .dhx_footer {
	background-color:#FFE763;
	border:1px solid #B7A543;
	color:#887A2E;
	overflow:hidden;
	width:100%;
	
	font-family:Tahoma;
	font-size:8pt;
}
.dhx_move_denied .dhx_cal_event .dhx_header, .dhx_move_denied .dhx_cal_event .dhx_title{
	cursor:default;
}
.dhx_cal_event .dhx_header{
	height:1px; 
	margin-left:1px; 
	border-width:1px 1px 0px 1px;
	cursor:pointer;
}
.dhx_cal_event .dhx_title {
	height:12px;
	border-width:0px 1px 1px 1px;
	border-bottom-style:dotted;
	
	font-size:7pt;
	font-weight:bold;
	text-align:center;
	
	background-position:right;
	background-repeat:no-repeat;
	cursor:pointer;
}
.dhx_cal_event .dhx_body, .dhx_cal_event.dhx_cal_select_menu .dhx_body{
	border-width:0 1px 1px 1px;
	padding:5px;
}
.dhx_resize_denied {
	cursor:default !important;
}
.dhx_cal_event .dhx_event_resize {
	cursor:s-resize;
}
.dhx_cal_event .dhx_footer, .dhx_cal_event .dhx_select_menu_footer{
	height:1px; 
	margin-left:2px; 
	border-width:0px 1px 1px 1px;
}
.dhx_cal_event_line{
	background-color:#FFE763;
	border:1px solid #B7A543;
	border-radius:3px;
	font-family:Tahoma;
	font-size:8pt;
	height:13px;
	padding-left:10px;
	color:#887A2E;
	cursor:pointer;
	overflow:hidden;
}
.dhx_cal_event_clear{
	font-family:Tahoma;
	font-size:8pt;
	height:13px;
	padding-left:2px;
	color:#887A2E;	
	white-space:nowrap;
	overflow:hidden;
	cursor:pointer;
}
.dhx_in_move{
	background-color:#FFFF80;
}
div.dhx_cal_editor{
	background-color:#FFE763;
	border:1px solid #B7A543;
	border-top-style:dotted;
	z-index:999;
	position:absolute;
	overflow:hidden;
}
textarea.dhx_cal_editor{
	width:100%; 
	height:100%;
	border:0px solid black;
	margin:none;
	padding:none;
	overflow:auto;
}
div.dhx_menu_head{
	background-image:url(imgs/controls.gif);
	background-position: 0px -43px;
	width:10px; height:10px;
	margin-left:5px; margin-top:1px;
	border:none;
	cursor:default;
}
div.dhx_menu_icon{
	background-image:url(imgs/controls.gif);
	width:20px; height:20px;
	margin-left:-5px; margin-top:0px;
	border:none;
	cursor:pointer;
}
div.icon_details{
	background-position: 0px 0px;
}
div.icon_edit{
	background-position: -22px 0px;
}
div.icon_save{
	background-position: -84px -1px;
}
div.icon_cancel{
	background-position: -62px 0px;
}
div.icon_delete{
	background-position: -42px 0px;
}
.dhx_unselectable, .dhx_unselectable div{
    -webkit-user-select:none;
    -moz-user-select:none;
    -moz-user-select:-moz-none;
}
.dhx_cal_light{
    background-color:#FFE763;
    border-radius:5px;
    font-family:Tahoma;
    font-size:8pt;
    border:1px solid #B7A64B;
    color:#887A2E;

    position:absolute;
    z-index:10001;

    width:580px;
    height:300px;

    box-shadow:5px 5px 5px #888;
}
.dhx_cal_light_wide{
    width:650px;
}
.dhx_mark{
    position:relative; top:3px;
    background-image:url('./imgs/controls.gif');
    background-position: 0px -43px;
    padding-left:10px;
}
.dhx_ie6 .dhx_mark{
    background-position: 6px -41px;
}

.dhx_cal_light select{
    font-family:Tahoma;
    font-size:8pt;
    color:#887A2E;
    padding:2px;
    margin:0px;
}
.dhx_cal_ltitle{
    padding:2px 0px 2px 5px;
    overflow:hidden;
    white-space:nowrap;
}
.dhx_cal_ltitle span{
    white-space:nowrap;
}
.dhx_cal_lsection{
    background-color:#DBCF8C;
    color:#FFF4B5;
    font-weight:bold;
    padding:5px 0px 3px 10px;
}
.dhx_section_time{
    background-color:#DBCF8C;
    white-space:nowrap;
}
.dhx_cal_lsection .dhx_fullday{
    float:right;
    margin-right:5px;
    color:#887A2E;
    font-size:12px;
    font-weight:normal;
    line-height:20px;
    vertical-align:top;
    cursor:pointer;
}
.dhx_cal_lsection{
    font-size:18px;
    font-family:Arial;
}
.dhx_cal_ltext{
    padding:2px	0px 2px 10px;
    overflow:hidden;
}
.dhx_cal_ltext textarea{
    background-color: #FFF4B5; /* #FFF4B5; should be the same for dhx_cal_larea, was transperent */
    overflow:auto;
    border:none;
    color:#887A2E;
    height:100%;
    width:100%;
    outline:none !important;
	resize: none;
}
.dhx_time{
    font-weight:bold;
}
.dhx_cal_light .dhx_title{
    padding-left:10px;
}
.dhx_cal_larea{
    border:1px solid #DCC43E;
    background-color:#FFF4B5;
    overflow:hidden;

    margin-left:3px;

    width:572px;
    height:1px;
}
.dhx_btn_set{
    padding:5px 10px 0px 10px;
    float:left;
}
.dhx_btn_set div{
    float:left;
    height:21px;
    line-height:21px;
    vertical-align:middle;
    cursor:pointer;
}
.dhx_save_btn{
    background-image:url('./imgs/controls.gif');
    background-position:-84px 0px;
    width:21px;

}
.dhx_cancel_btn{
    background-image:url('./imgs/controls.gif');
    background-position:-63px 0px;
    width:20px;
}
.dhx_delete_btn{
    background-image:url('./imgs/controls.gif');
    background-position:-42px 0px;
    width:20px;
}
.dhx_cal_cover{
    width:100%;
    height:100%;
    position:absolute;
    z-index:10000;
    top:0px;
    left:0px;
    background-color:black;

    opacity:0.1;
    filter:alpha(opacity=10);
}
.dhx_custom_button{
    padding:0px 3px 0px 3px;
    color:#887A2E;
    font-family:Tahoma;
    font-size:8pt;
    background-color:#FFE763;
    font-weight:normal;
    margin-right:5px;
    margin-top:0px;
    cursor:pointer;
}
.dhx_custom_button div{
    cursor:pointer;
    float:left;
    height:21px;
    line-height:21px;
    vertical-align:middle;
}


.dhx_cal_light_wide .dhx_cal_larea{
    border-top-width:0px;
}
.dhx_cal_light_wide .dhx_cal_lsection{
    border:0px;
    float:left;
    text-align:right;
    width:100px;
    height:20px;
    font-size:16px;
    padding: 5px 0px 0px 10px;
}
.dhx_cal_light_wide .dhx_wrap_section{
    border-top:1px solid #DBCF8C;
    position:relative;
    background-color:#DBCF8C;
    overflow:hidden;
}
.dhx_cal_light_wide .dhx_section_time{
    padding-top:2px !important;
    height:20px !important;
}
.dhx_section_time{
    text-align: center;
}
.dhx_cal_light_wide .dhx_cal_larea{
    width:730px;
}
.dhx_cal_light_wide{
    width:738px;
}

.dhx_cal_light_wide .dhx_section_time{
    background:transparent;
}
.dhx_cal_light_wide .dhx_cal_checkbox label{
    padding-left:0px;
}
.dhx_cal_wide_checkbox input{
    margin-top:8px;
    margin-left:14px;
}
.dhx_cal_light input{
    font-family:Tahoma;
    font-size:8pt;
    color:#887A2E;
}
.dhx_cal_light_wide .dhx_cal_lsection .dhx_fullday{
    float:none;
    margin-right:0px;
    color:#FFF4B5;
    font-weight:bold;
    font-size:16px;
    font-family:Arial;
    cursor:pointer;
}
.dhx_custom_button{
    float: right;
    height: 21px;
	width:90px;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    -ms-border-radius: 4px;
    -o-border-radius: 4px;
    border-radius: 4px;
}
.dhx_cal_light_wide .dhx_custom_button {
    position:absolute;
    top:0;
    right:0;
    margin-top: 2px;
}
.dhx_cal_light_wide .dhx_repeat_right {
    margin-right: 55px;
}
.dhx_minical_popup{
	position:absolute;z-index:10100;
	width:251px; height:175px;
}
.dhx_scale_bar_header {
    position: absolute;
    border-bottom: 1px dotted #8894A3;
    width: 100%;
}
.dhx_expand_icon {
	position:absolute; top:0px; right:0px; 
	background-image:url(./imgs/collapse_expand_icon.gif);
	width:18px; height:18px;
	cursor:pointer;
	background-position:0px 18px;
	z-index:16;
}
.dhx_scheduler_agenda .dhx_cal_data {
	background-image:url(./imgs/databg.png);
}
.dhx_agenda_area{
	width:100%;
	overflow-y:auto;
	background-image:url(./imgs/databg.png);
}
.dhx_agenda_line{
	height:21px;
	clear:both;
	overflow:hidden;
}
.dhx_agenda_line div{
	float:left; 
	width:188px;
	border-right:1px dotted #8894A3;
	text-align:center;
	line-height:21px;
	overflow:hidden;
}
.dhx_agenda_area .dhx_agenda_line div{
	border-right:0px dotted #8894A3;	
}
.dhx_v_border{
	position:absolute;
	left:187px;
	top:0;
	border-right:1px dotted #8894A3;
	width:1px;
	height:100%;
}
.dhx_agenda_line .dhx_event_icon{
	width:20px;
	border-width:0px;
	background:url(./imgs/icon.png) no-repeat;
	background-position: 5px 4px;
	cursor:pointer;
}
.dhx_agenda_line span{
	padding-left:5px;
	line-height:21px;
}


.dhx_year_body{
  border-left:1px dotted #586A7E;
}
.dhx_year_week{
  position:relative;
}
.dhx_scale_bar_last{
  border-right:1px dotted #586A7E;      
}   
.dhx_year_month{
  height:18px;
  padding-top:3px;
  border:1px dotted #586A7E;
  text-align:center;
  vertical-align:middle;
}
.dhx_year_body .dhx_before .dhx_month_head, .dhx_year_body .dhx_after .dhx_month_head, .dhx_year_body .dhx_before .dhx_month_head a, .dhx_year_body .dhx_after .dhx_month_head a{
  color:#E2E3E6 !important;
}
.dhx_year_body .dhx_month_body{
  height:0px;
  overflow:hidden;
}
.dhx_month_head.dhx_year_event{
  background-color:#FFE763;
}
.dhx_year_body .dhx_before .dhx_month_head, .dhx_year_body .dhx_after .dhx_month_head{
	cursor: default;
}
.dhx_tooltip{
  border:1px solid #BBBBBB;
  background-image:url(./imgs/databg.png);
  position:absolute;
  z-index:9998;
  width:300px; 
  height:auto;
  font-family:Tahoma;
  font-size:8pt;
  overflow:hidden;
}

.dhx_tooltip_line{
	line-height:20px;
	height:20px;
	overflow:hidden;
}

.dhx_tooltip_line .dhx_event_icon{
	width:20px; height:20px;
	padding-right:10px;
	float:left;
	border-width:0px;
	position:relative;
	background:url(./imgs/icon.png) no-repeat;
	background-position: 5px 4px;
	cursor:pointer;
}

.dhx_tooltip_date{
	float:left;
	width:auto;
	padding-left:5px;
	text-align:center;
}

.dhx_text_disabled{
	color:#887A2E;
	font-family:Tahoma;
	font-size:8pt;
}

.dhx_mini_calendar{
	-moz-box-shadow:5px 5px 5px #888;	/*Doesn't work in IE*/
	-khtml-box-shadow: 5px 5px 5px #888;
}

.dhx_mini_calendar .dhx_month_head{
	cursor:pointer;
}
.dhx_mini_calendar .dhx_calendar_click{
	background-color: #C2D5FC;
}
.dhx_cal_navline div.dhx_minical_icon{
	width:18px;
	height:18px;
	left:190px;
	top:1px;
	cursor:pointer;
	background-image:url(./imgs/calendar.gif);
}

.dhx_matrix_scell {
	height: 100%;
}

.dhx_matrix_cell, .dhx_matrix_scell{
	overflow:hidden;
	text-align:center;
	vertical-align:middle;
	border-bottom:1px dotted #8894A3;
	border-right:1px dotted #8894A3;	
}
.dhx_matrix_cell{
	background-color:white;
}
.dhx_matrix_line{
	overflow: hidden;
}
.dhx_matrix_cell div, .dhx_matrix_scell div{ 
	overflow:hidden;
	text-align:center;
    height:auto; 
}

.dhx_cal_lsection .dhx_readonly{
	font-size:9pt;
	font-size:8pt;
	padding:2px;
	color:#887A2E;
}
.dhx_cal_event_line .dhx_event_resize {
	cursor: w-resize;
	background: url(./imgs/resize_dots.png) repeat-y;
	position: absolute;
	top: 0;
	width: 4px;
}
.dhx_event_resize_start {
	left: 0;
}
.dhx_event_resize_end {
	right: 0;
}

/* Tree view */
.dhx_matrix_scell.folder, .dhx_data_table.folder .dhx_matrix_cell{
	background-color: #969394;
	cursor: pointer;
}
.dhx_matrix_scell .dhx_scell_level0{
	padding-left: 5px;
}
.dhx_matrix_scell .dhx_scell_level1{
	padding-left: 20px;
}
.dhx_matrix_scell .dhx_scell_level2{
	padding-left: 35px;
}
.dhx_matrix_scell .dhx_scell_level3{
	padding-left: 50px;
}
.dhx_matrix_scell .dhx_scell_level4{
	padding-left: 65px;
}

.dhx_matrix_scell.folder{
	font-weight: bold;
	text-align: left;
}
.dhx_matrix_scell.folder .dhx_scell_expand{
	float: left;
	width: 10px;
	padding-right:3px;
}
.dhx_matrix_scell.folder .dhx_scell_name{
	float: left;
	width: auto;
}
.dhx_matrix_scell.item .dhx_scell_name{
	padding-left:15px;
	text-align: left;
}
.dhx_data_table.folder .dhx_matrix_cell{
    border-right: 0;
}
.dhx_section_timeline {
	overflow: hidden;
	padding: 4px 0 2px 10px;
}
.dhx_section_timeline select{
	width: 552px;
}

/* Tree view end*/

/* Map view */
.dhx_map_area{
	width:100%;
	height:100%;
	overflow-y: auto;
	overflow-x: hidden;
	background-image:url(./imgs/databg.png);
}
.dhx_map_line .dhx_event_icon{
	width:20px;
	border-width:0px;
	background:url(./imgs/icon.png) no-repeat;
	background-position: 5px 4px;
	cursor:pointer;
}
.dhx_map_line{
	height:21px;
	clear:both;
	overflow:hidden;
}
.dhx_map {
	position:absolute;
}
.dhx_map_line div{
	float:left; 
	border-right:1px dotted #8894A3;
	text-align:center;
	line-height:21px;
	overflow:hidden;
}
.dhx_map_line .headline_description{
	float:left; 

	border-right:1px dotted #8894A3;
	text-align:center;
	line-height:21px;
	overflow:hidden;
}
.dhx_map_line .dhx_map_description{
	float:left; 
	border-right: 0 dotted #8894A3;
	text-align:center;
	line-height:21px;
	overflow:hidden;
}
.dhx_map_line .headline_date, .dhx_map_line .headline_description {
	border-left: 0;
}
.dhx_map_line .line_description {
	float:left; 
	border-right:1px dotted #8894A3;
	text-align:left;
	padding-left:5px;
	line-height:21px;
	overflow:hidden;
}
.dhx_map_line.highlight{
	background-color: #C4C5CC;
}
.dhx_map_area .dhx_map_line div{
	border-right:0px dotted #8894A3;	 
}
/* Map view end */

/* dhtmlXTooltip start */
.dhtmlXTooltip.tooltip{
	-moz-box-shadow:3px 3px 3px #888888;
	-webkit-box-shadow:3px 3px 3px #888888;
	-o-box-shadow:3px 3px 3px #888888;
	box-shadow:3px 3px 3px #888888;
	filter:
		progid:DXImageTransform.Microsoft.Shadow(color='#888888', Direction=135, Strength=5)
	;
	background-color:white;
	border-left:1px dotted #887A2E;
	border-top:1px dotted #887A2E;
	color:#887A2E;
	cursor:default;
	padding:10px;
	position:absolute;
	z-index:500;
}
/* dhtmlXTooltip end */

/* Lightbox checkbox section */
.dhx_cal_checkbox label {
	padding-left: 5px;
}
/* Lightbox checkbox section end */


/* Lightbox radiobuttons section */
.dhx_cal_light .radio {
	padding: 2px 0px 2px 10px;
}
.dhx_cal_light .radio input,  .dhx_cal_light .radio label{
	line-height: 15px;
}
.dhx_cal_light .radio input {
	vertical-align: middle;
	margin: 0px;
	padding: 0px;
}
.dhx_cal_light .radio label {
	vertical-align: middle;
	padding-right: 10px;
}
/* Lightbox radiobuttons section end */


/* Lightbox dhtmlx combo section */
.dhx_cal_light .combo {
	padding: 4px;
}
.dhx_cal_light_wide .dhx_combo_box/*, .dhx_cal_light_wide .combo*/ {
    width: 608px !important;
    left: 10px;
}
/* Lightbox dhtmlx combo section end */

/* Agenda week start */
.dhx_wa_column {
    float: left;
}
.dhx_wa_column_last .dhx_wa_day_cont{
    border-left: 1px dotted #8894A3;
}
.dhx_wa_scale_bar {
    font-family: Tahoma;
    padding-left: 10px;
    font-size: 11px;
	border-top: 1px dotted #8894A3;
	border-bottom: 1px dotted #8894A3;
}
.dhx_wa_day_data {
    background-color: #FCFEFC;
    overflow-y: auto;
}
.dhx_wa_ev_body {
    border-bottom: 1px dotted #778899;
    font-size: 12px;
    padding: 5px 0 5px 7px;
}
.dhx_wa_dnd {
	font-family: Tahoma;
    position: absolute;
	padding-right: 7px;
	color: #887AE2 !important;
	background-color: #FFE763 !important;
	border: 1px solid #B7A543;
}
.dhx_cal_event_selected{
    background-color: #9cc1db;
    color: white;
}
/* Agenda week end */

/* timeline second scale start */
.dhx_second_scale_bar {
    border-bottom: 1px dotted #586A7E;
    padding-top: 2px;
}
/* timeline second scale end */


/* grid view */

.dhx_cal_header div div{
    border-left: 1px dotted #8894A3;
}

.dhx_grid_area{
	width:100%;
	height:100%;
	overflow-y:auto;
    background-color:#FCFEFC;
}
.dhx_grid_area table{
    border-collapse: collapse;
    border-spacing: 0;
    width:100%;
    table-layout:fixed;
}
.dhx_grid_area td{
    table-layout:fixed;
    text-align:center;
}

.dhx_grid_line{
	height:21px;
	clear:both;
	overflow:hidden;
}
.dhx_grid_line div{
	float:left;
    cursor:default;
    padding-top: 0;
    padding-bottom: 0;
	text-align:center;
	line-height:21px;
	overflow:hidden;
}

.dhx_grid_area td, .dhx_grid_line div{
    padding-left:8px;
    padding-right:8px;
}


.dhx_grid_area tr.dhx_grid_event{
    height:21px;
	overflow:hidden;
    margin:0 0 1px 0;
}
.dhx_grid_area tr.dhx_grid_event td{
    /*borders for old ies*/
    border-bottom:1px solid #ECEEF4;
}
.dhx_grid_area tr.dhx_grid_event:nth-child(2n+1) td, .dhx_grid_area tr.dhx_grid_event:nth-child(2n) td{
    border-bottom-width:0px;
    border-bottom-style:none;
}
.dhx_grid_area tr.dhx_grid_event:nth-child(2n){
    background-color:#ECEEF4;;
}
.dhx_grid_area .dhx_grid_dummy{
    table-layout:auto;
    margin:0 !important;
    padding:0 !important;
}

.dhx_grid_v_border{
	position:absolute;
	border-right:1px solid #A4BED4;
	width:1px;
	height:100%;
}

.dhx_grid_event_selected{
    background-color: #9cc1db !important;
    color: white !important;
}

.dhx_grid_sort_desc .dhx_grid_view_sort{
	background-position: 0 -55px;
}
.dhx_grid_sort_asc .dhx_grid_view_sort{
	background-position: 0 -66px;
}
.dhx_grid_view_sort{
	width:10px;
	height:10px;
	position: absolute;
	border:none !important;
	top: 5px;
	background-repeat:no-repeat;
	background-image: url(./imgs/images.png);
}
/* end grid */

/* marked timespans */
.dhx_marked_timespan {
	position: absolute;
	width: 100%;
}
.dhx_time_block {
	position:absolute;
	width:100%;
	background:silver;
	opacity:0.4;
	filter:alpha(opacity=40);
	z-index:1;
}
.dhx_time_block_reset {
	opacity: 1;
	filter:alpha(opacity=100);
}
.dhx_scheduler_month .dhx_marked_timespan {
	display: none;
}
.dhx_mini_calendar .dhx_marked_timespan {
	display: none;
}
/* now time */
.dhx_now_time {
	width:100%;
	border-bottom:2px dotted red;
	z-index: 1;
}
.dhx_scheduler_month .dhx_now_time {
	border-bottom: 0;
	border-left: 2px dotted red;
}
.dhx_matrix_now_time {
	border-left:2px dotted red;
	z-index: 1;
}


/*IE*/
div.dhx_form_repeat input.radio 	{ margin:-4px 0 0 -4px !ie; }
div.dhx_form_repeat input.checkbox 	{ margin:0 0 0 -4px !ie; }

/*All*/  
.dhx_form_repeat, .dhx_form_repeat input {
    padding:0;
    margin:0;
    padding-left:5px;
    font-family:Tahoma, Verdana;
    font-size:11px;
    line-height:24px;
}

.dhx_form_repeat {
    overflow:hidden;
    /*height:115px;*/
    height:0px;
    background-color: #FFF4B5;
    /*border: 1px solid #DCC43E;*/
}

.dhx_cal_light_wide .dhx_form_repeat {
    background-color: transparent;
}


.dhx_repeat_center, .dhx_repeat_left{
    height:115px;
    padding:10px 0 10px 10px;
    float:left;
}

.dhx_repeat_left{
    width:95px;
}

.dhx_repeat_center{
    width:335px;
    margin-top:12px;
}

.dhx_repeat_divider{
    float:left;
    height:115px;
    border-left:1px dotted #DCC43E;
    /*background-color: #DCC43E;*/
    width:1px;
}

.dhx_repeat_right {
    float:right;
    height:115px;
    width:160px;
    padding:10px 3px 10px 10px;
    margin-top:7px;
}

input.dhx_repeat_text {
    height:16px;
    width: 27px;
    margin: 0 4px 0 4px;
    line-height:18px;
    padding: 0 0 0 2px;
}

.dhx_form_repeat select {
    height: 20px;
    width: 87px;
    padding:0 0 0 2px;
    margin: 0 4px 0 4px;
}

input.dhx_repeat_date{
    height: 18px;
    width: 80px;
    padding:0 0 0 2px;
    margin: 0 4px 0 4px;
    background-repeat:no-repeat;
    background-position:64px 0;
    border:1px #7f9db9 solid;
    line-height:18px;
}

input.dhx_repeat_radio {
    margin-right:4px;
}

input.dhx_repeat_checkbox {
    margin:4px 4px 0 0;
}

.dhx_repeat_days td {
    padding-right:5px;
}
.dhx_repeat_days label {
    font-size:10px;
}
.dhx_custom_button{
	width:90px;
    -webkit-border-radius: 4px;
    -moz-border-radius: 4px;
    -ms-border-radius: 4px;
    -o-border-radius: 4px;
    border-radius: 4px;
}
.dhx_custom_button_recurring{
	background-image:url(./imgs/but_repeat.gif);
	background-position:-5px 20px;
	width:20px;
	margin-right:10px;
}

/* increase width of lightbox */
.dhx_cal_light_rec{
    width:640px;
}
.dhx_cal_light_rec .dhx_cal_larea{
    width:632px;
}
.dhx_cal_light_rec.dhx_cal_light_wide{
    width:816px;
}
.dhx_cal_light_rec.dhx_cal_light_wide .dhx_cal_larea{
    width:808px;
}